@@ -3,14 +3,14 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Dec  8, 1994
- * Revised: Jul 10, 2001
+ * Revised: Jan 17, 2002
  *
  * Code:
  */
 
 #include "mew.h"
 
-private char version_message[] = "version 0.20 20010710 Kazu Yamamoto";
+private char version_message[] = "version 2.2 20020117 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 #include <sys/types.h>
@@ -85,7 +85,7 @@ private void check_8bit(void);
 private void
 usage(const char *progname)
 {
-	fprintf(stderr, "usage: %s [-e|-d|-8] [-b|-q|-g|-u] [-l length] [-t] [infile [outfile]]\n", progname);
+	fprintf(stderr, "Usage: %s [-e|-d|-8] [-b|-q|-g|-u] [-l length] [-t] [infile [outfile]]\n", progname);
 }
 
 private const char *
@@ -123,7 +123,7 @@ help(const char *progname)
 {
 	const char **p = help_message;
 
-	fprintf(stderr, "help: %s\n\n", progname);
+	fprintf(stderr, "Help: %s\n\n", progname);
 	fprintf(stderr, " MIME encoder/decoder.\n\n");
 	usage(progname);
 	while (*p) fprintf(stderr, "%s\n", *p++);
@@ -1125,7 +1125,7 @@ main(int argc, char **argv)
 }
 
 /* 
- * Copyright (C) 1994-2001 Mew developing team.
+ * Copyright (C) 1994-2002 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
