@@ -3,14 +3,14 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Jul  7, 2000
- * Revised: Jul 10, 2001
+ * Revised: Jan 17, 2002
  *
  * Code:
  */
 
 #include "mew.h"
 
-private char version_message[] = "version 0.21 20010908 Kazu Yamamoto";
+private char version_message[] = "version 2.2 20020117 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -124,8 +124,8 @@ private char *eoh(char *, char *);
 private void init_fields(char *);
 private void print_field(char *, int, char *, char *);
 private void init_search(char *, int);
-private char *strcasechr(char *, int);
-private char *strcasestr(char *, char *);
+private char *mystrcasechr(char *, int);
+private char *mystrcasestr(char *, char *);
 private int  print_for_scan(FILE *, char *, char *);
 private int  print_for_sort(FILE *, char *, char *);
 private int  print_for_pick(FILE *, char *, char *);
@@ -183,7 +183,7 @@ private void
 help(const char *progname) {
 	const char **p = help_message;
 
-	fprintf(stderr, "help: %s\n\n", progname);
+	fprintf(stderr, "Help: %s\n\n", progname);
 	fprintf(stderr, " Message scanner.\n\n");
 	usage(progname);
 	while (*p) fprintf(stderr, "%s\n", *p++);
@@ -473,7 +473,7 @@ init_search(char *buf, int lim) {
 }
 
 private char *
-strcasechr(char *s, int c)
+mystrcasechr(char *s, int c)
 {
 	int lc = tolower(c);
 	int uc = toupper(c);
@@ -486,12 +486,12 @@ strcasechr(char *s, int c)
 }
 
 private char *
-strcasestr(char *s1, char *s2)
+mystrcasestr(char *s1, char *s2)
 {
 	char *p;
 	unsigned int len = strlen(s2);
 
-	for (p = s1; (p = strcasechr(p, *s2)) != NULL; p++)
+	for (p = s1; (p = mystrcasechr(p, *s2)) != NULL; p++)
 		if (strncasecmp(p, s2, len) == 0)
 			return p;
 	return NULL;
@@ -513,7 +513,7 @@ search_string(char *key, char *value, int case_sensitive) {
 				return TRUE;
 			}
 		} else {
-			if (strcasestr(p, value) != NULL) {
+			if (mystrcasestr(p, value) != NULL) {
 				*end = tmp;
 				return TRUE;
 			}
@@ -540,7 +540,7 @@ search_string(char *key, char *value, int case_sensitive) {
 					return TRUE;
 				}
 			} else {
-				if (strcasestr(beg, value) != NULL) {
+				if (mystrcasestr(beg, value) != NULL) {
 					*end = tmp;
 					return TRUE;
 				}
@@ -751,6 +751,8 @@ exec_init(unsigned int num) /* num == 0 */
 	int childpid;
 #endif /* HAVE_FORK */
 
+	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
+		warn_exit("folder name is too long.\n");
 	strcpy(Current_folder, Folders[0].folder);
 	ch_folder(Current_folder);
 
@@ -812,6 +814,8 @@ exec_getfile(char **filename, char **foldername)
 		if (STRCMP(p, CHDIR) == 0) {
 			p = p + strlen(CHDIR);
 			while (*p == SP || *p == TAB) p++;
+			if (strlen(p) >= sizeof(Current_folder))
+				warn_exit("folder name is too long.\n");
 			strcpy(Current_folder, p);
 			ch_folder(Current_folder);
 			*foldername = Current_folder;
@@ -841,6 +845,8 @@ stdin_init(unsigned int num) /* num == 0 */
 		if (freopen(Input_file, "r", stdin) == NULL)
 			warn_exit("can't open %s.\n", Input_file);
 
+	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
+		warn_exit("folder name is too long.\n");
 	strcpy(Current_folder, Folders[0].folder);
 	ch_folder(Current_folder);
 }
@@ -1031,7 +1037,7 @@ main(int argc, char **argv)
 }
 
 /* 
- * Copyright (C) 2000-2001 Mew developing team.
+ * Copyright (C) 2000-2002 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
