@@ -3,7 +3,7 @@
 ;; Author: Shun-ichi TAHARA <jado@flowernet.gr.jp>
 ;;	   Hideyuki SHIRAI <shirai@mew.org>
 ;;
-;; Time-stamp: <06/29/2001 11:58 shirai>
+;; Time-stamp: <09/05/2001 11:35 shirai>
 
 ;;; Commentary:
 ;;
@@ -188,8 +188,6 @@ return t, otherwise nil."
 (defvar mew-fancy-summary-thread-column nil)
 (make-variable-buffer-local 'mew-fancy-summary-thread-column)
 
-(defvar mew-fancy-summary-thread-regex nil)
-
 ;;; Initialization
 
 (add-hook 'mew-summary-mode-hook 'mew-fancy-summary-enable)
@@ -207,20 +205,8 @@ return t, otherwise nil."
 
 (defadvice mew-addrbook-setup (after hl-setup activate)
   "Setup fancy-summary when starting up Mew or executing \"Z\"."
-  (mew-fancy-summary-regex-setup)
   (mew-fancy-summary-special-setup))
 
-(defun mew-fancy-summary-regex-setup ()
-  (setq mew-fancy-summary-thread-regex
-	(concat "\\("
-		(if mew-use-fancy-thread
-		    (mapconcat
-		     '(lambda (indent)
-			(regexp-quote indent))
-		     mew-fancy-thread-indent-strings "\\|")
-		  mew-thread-indent-string)
-		"\\)+")))
-
 (defun mew-fancy-summary-special-setup ()
   (setq mew-fancy-summary-special-list mew-fancy-summary-special-persons)
   (if mew-fancy-summary-special-addrbook
@@ -293,9 +279,7 @@ mark line is done by mew-fancy-summary."
     (mew-fancy-summary-remove-invisible)
     (setq mew-fancy-summary-scan-form
 	  (mew-summary-scan-form (substring (mew-summary-folder-name 'ext) 1)))
-    (setq mew-fancy-summary-thread-column
-	  (mew-summary-scan-form
-	   (substring (mew-summary-folder-name 'ext) 1) 'column))
+    (setq mew-fancy-summary-thread-column (mew-vinfo-get-column))
     ;; XEmacs + lazy-lock ???
     (when mew-xemacs-p
       (let* ((win (selected-window))
@@ -457,6 +441,8 @@ mark line is done by mew-fancy-summary."
 	(setq range "[^\r\n]*[^ \r\n]"))
     (setq face (mew-fancy-summary-get-face elem extended))
     (cond
+     ((eq elem t)	;; thread indent
+      nil)
      ((eq elem 'num)
       (list (cons elem face)))
      ((eq elem 'type)
@@ -468,7 +454,14 @@ mark line is done by mew-fancy-summary."
        (t
 	(list (cons range nil)))))
      ((eq elem 'thread)
-      (list (cons mew-fancy-summary-thread-regex face)))
+      (let ((indent (get-text-property (point) 'mew-thread-indent)))
+	(if (or (null indent) (= indent 0))
+	    nil
+	  (list (cons (string-width
+		       (mew-buffer-substring
+			(point)
+			(next-single-property-change (point) 'mew-thread-indent)))
+		      face)))))
      ((eq elem 'from)
       (let* ((beg (point))
 	     (entry (mew-buffer-substring
