@@ -146,7 +146,7 @@ will be also shown.")
 		 (setq buffer-read-only t))))
        (let ((alist (mew-refile-view-make-alist refile))
 	     tmpalist view summary num numlist)
-	 (setq view (mew-pop-to-buffer bufname))
+	 (setq view (pop-to-buffer bufname))
 	 (setq buffer-read-only nil)
 	 (erase-buffer)
 	 (mew-buffers-setup bufname)
@@ -206,7 +206,9 @@ will be also shown.")
 	(progn
 	  (message "No Summary buffer for %s" original-folder)
 	  nil)
-      (mew-pop-to-buffer original-folder)
+      (if (get-buffer-window original-folder)
+	  (select-window (get-buffer-window original-folder))
+	(mew-summary-switch-to-folder original-folder))
       (if num (mew-summary-jump-message num))
       t)))
 
@@ -358,7 +360,7 @@ If this message has multi-refile folders, remove one of them."
 	     (mew-summary-delete 1)))
 	   (mew-refile-view)))
       ;; we are out of mew summary buffer now
-      (mew-pop-to-buffer orig-buff)
+      (pop-to-buffer orig-buff)
       (if (< orig-point (point-max))
 	  (goto-char orig-point)
 	(goto-char (point-max)))
