@@ -317,7 +317,7 @@ fields in the header according to the new value."
       (setq eoh (point))
       (goto-char (point-min))
       (cond
-       ((re-search-forward "^Resent" eoh t)
+       ((mew-draft-resent-p eoh)
 	(setq from mew-resent-from:)
 	;; (setq cc mew-resent-cc:)
 	(setq dcc mew-resent-dcc:))
@@ -369,7 +369,7 @@ fields in the header according to the new value."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2001 Mew developing team.
+;; Copyright (C) 1999-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
