@@ -613,6 +613,9 @@ Return a part syntax after moving the beginning of the content body."
 ;;;
 
 (defun mew-decode-multipart-boundary-regex (boundary)
+  ;; for broken MUAs which uses non-ASCII boundaries
+  ;; This works only on Emacs 21.
+  (setq boundary (mew-set-string-multibyte boundary))
   (concat "^--" (regexp-quote boundary) "\\(--\\|\\)[ \t]*$"))
 
 (defsubst mew-decode-multipart-boundary-cont ()
@@ -902,7 +905,7 @@ Return a part syntax after moving the beginning of the content body."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
