@@ -260,11 +260,15 @@ Moreover, '~/.mew-fib' supports aliases like;
 	    (delete-file buffer-auto-save-file-name))
 	(mew-remove-buffer draftname)))
     (cond
+     (mew-use-other-frame
+      (setq switch-func (function switch-to-buffer-other-frame)))
      ((eq switch-func nil)
       (setq switch-func (function switch-to-buffer)))
      ((eq switch-func t)
       (setq switch-func (function switch-to-buffer-other-window))))
-    (funcall switch-func (find-file-noselect draft-path))
+    (mew-frwlet
+     mew-cs-m17n mew-cs-dummy
+     (funcall switch-func (find-file-noselect draft-path)))
     ;; draft buffer
     (mew-set-buffer-cs mew-cs-m17n)
     ;; copy config, first
@@ -671,16 +675,24 @@ The citation style is 'from_address> ', e.g. 'kazu> '"
 	(message "Draft was killed"))
     (message "Draft was not killed")))
 
-(defun mew-draft-insert-signature ()
+(defun mew-draft-insert-signature (&optional arg)
   "Insert the signature file specified by mew-signature-file.
 If attachments exist and mew-signature-as-lastpart is *non-nil*,
 the file is attached to the last part. Otherwise, the file is 
 inserted into the body. If mew-signature-insert-last is *non-nil*,
 the file is inserted to the end of the body. Otherwise, inserted
-the cursor position."
-  (interactive)
-  (let ((sigfile
-	 (expand-file-name (mew-signature-file (mew-tinfo-get-case)))))
+the cursor position. If excuted with '\\[universal-argument]',
+you can set the case."
+  (interactive "P")
+  (let (case sigfile)
+    (cond
+     ((stringp arg)
+      (setq case arg))
+     (arg
+      (setq case (mew-input-case (mew-tinfo-get-case) "Signature")))
+     (t
+      (setq case (mew-tinfo-get-case))))
+    (setq sigfile (expand-file-name (mew-signature-file case)))
     (if (not (file-exists-p sigfile))
 	(message "No signature file %s" sigfile)
       (if (and (mew-attach-p) mew-signature-as-lastpart)
@@ -763,6 +775,40 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 ;;; Sending and Queuing
 ;;;
 
+(defun mew-draft-remove-illegal-fields ()
+  (when (mew-header-end)
+    (save-excursion
+      (save-restriction
+	(goto-char (mew-header-end))
+	(if (not (bolp)) (insert "\n"))
+	(narrow-to-region (point-min) (mew-header-end))
+	(let (beg med str)
+	  (mew-elet
+	   ;; removing null lines
+	   (goto-char (point-min))
+	   (while (and (re-search-forward "^$" nil t)
+		       (not (eobp)))
+	     (delete-char 1))
+	   ;; removing fields which do not have value.
+	   (goto-char (point-min))
+	   (while (not (eobp))
+	     (if (not (looking-at mew-keyval))
+		 (forward-line)
+	       (setq beg (match-beginning 0))
+	       (setq med (match-end 0))
+	       (forward-line)
+	       (mew-header-goto-next)
+	       (setq str (buffer-substring med (1- (point))))
+	       ;; str may consists of multiple lines
+	       ;; So, "$" does not work. We need to use "[^ ]".
+	       (unless (string-match "[^ \t\n]" str)
+		 (delete-region beg (point)))))))))))
+
+(defun mew-draft-resent-p (end)
+  (let ((case-fold-search t))
+    (save-excursion
+      (re-search-forward mew-resent-regex end t))))
+
 (defun mew-draft-process-message (action &optional privacy signer)
   (let* ((buf (current-buffer))
 	 (case (mew-tinfo-get-case))
@@ -780,6 +826,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
     (setq pnm (mew-smtp-info-name case))
     (if (mew-smtp-get-lock pnm)
 	(message "Another message is being sent. Try later")
+      (mew-draft-remove-illegal-fields)
       (unless (string= old-case case)
 	(mew-tinfo-set-case case)
 	(mew-draft-mode-name (mew-tinfo-get-hdr-file))
@@ -791,7 +838,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
       ;; Check resentp
       (save-excursion
 	(goto-char (point-min))
-	(setq resentp (re-search-forward "^Resent" (mew-header-end) t)))
+	(setq resentp (mew-draft-resent-p (mew-header-end))))
       ;; Ask Subject: before the query of "Really send".
       ;; Typing C-g here gets back to the draft.
       (mew-encode-ask-subject)
@@ -825,6 +872,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 	      (setq err t)))))
       (if (not err)
 	  (run-hooks 'mew-real-send-hook)
+	(mew-current-set-window-config)
 	(switch-to-buffer buf)
 	(delete-other-windows)))))
 
@@ -845,7 +893,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
