@@ -281,7 +281,7 @@ in the context of FUNC."
 
 (defun mew-replace-white-space (string)
   "Replace white characters to a space."
-  (while (string-match "\t+" string)
+  (while (string-match "[\n\t]+" string)
     (setq string (replace-match " " nil t string)))
   (while (string-match "  +" string)
     (setq string (replace-match " " nil t string)))
@@ -329,6 +329,10 @@ Words are separated by '/' and '-'."
 (defsubst mew-insert-message (fld msg rcs size)
   (let ((file (mew-expand-folder fld msg)))
     (cond
+     ((not (file-readable-p file))
+      (error "%s%s does not exist" (file-name-as-directory fld) msg))
+     ((= (mew-file-get-size file) 0)
+      (error "The size of %s%s is 0" (file-name-as-directory fld) msg))
      ((file-readable-p file)
       (let ((old-cs (and (boundp 'buffer-file-coding-system)
 			 buffer-file-coding-system)))
@@ -338,9 +342,7 @@ Words are separated by '/' and '-'."
 	(if (boundp 'buffer-file-coding-system)
 	    (setq buffer-file-coding-system old-cs)))
       ;; return physical size
-      (cons (mew-file-get-time file) (mew-file-get-size file)))
-     (t
-      (error "%s%s does not exist" (file-name-as-directory fld) msg)))))
+      (cons (mew-file-get-time file) (mew-file-get-size file))))))
 
 (defsubst mew-insert-manual (&rest args)
   (insert (substitute-command-keys (apply (function concat) args))))
@@ -826,17 +828,21 @@ Does not examine containing directories for links."
                   (device-connection)
 		(cdr (assq 'display (frame-parameters)))))
         (process-environment (copy-sequence process-environment)))
-    (setenv "DISPLAY" disp)
+    (if disp (setenv "DISPLAY" disp))
     (apply (function start-process) name buffer program program-args)))
 
 (defun mew-start-process-lang (name buffer program &rest program-args)
   (let ((process-environment (copy-sequence process-environment)))
-    (setenv "LANGUAGE" "en")
+    (setenv "LANGUAGE" "C")
+    (setenv "LC_ALL" "C")
+    (setenv "LANG" "C")
     (apply (function start-process) name buffer program program-args)))
 
 (defun mew-call-process-lang (prog &optional infile buffer display &rest args)
   (let ((process-environment (copy-sequence process-environment)))
-    (setenv "LANGUAGE" "en")
+    (setenv "LANGUAGE" "C")
+    (setenv "LC_ALL" "C")
+    (setenv "LANG" "C")
     (apply (function call-process) prog infile buffer display args)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1164,6 +1170,11 @@ by side-effect."
   (if (fboundp 'set-buffer-multibyte)
       (set-buffer-multibyte arg)))
 
+(defsubst mew-set-string-multibyte (str)
+  (if (fboundp 'string-as-multibyte)
+      (string-as-multibyte str)
+    str))
+
 (defsubst mew-multibyte-string-p (str)
   (if (fboundp 'multibyte-string-p)
       (multibyte-string-p str)))
@@ -1178,8 +1189,6 @@ by side-effect."
       (string-to-int port)
     port))
 
-(provide 'mew-func)
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; 
 ;;; sit-for
@@ -1210,9 +1219,11 @@ by side-effect."
 (defsubst mew-timing ()
   (sit-for 0.01))
 
+(provide 'mew-func)
+
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
