@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Oct  2, 1996
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -33,7 +32,7 @@
 (defun mew-header-get-value (field)
   "currently, when no match, it returns nil."
   ;; maybe called in narrowed region.
-  ;; we can't widen for citation.
+  ;; we cannot widen for citation.
   (let ((case-fold-search t)
 	(regex (format "^%s[ \t]*" field))
 	start match ret)
@@ -168,7 +167,7 @@
 (defsubst mew-draft-header-fill (field value)
   (unless (mew-header-existp field) (mew-draft-header-insert field value)))
 
-(defun mew-header-insert (key value)
+(defun mew-header-insert (key value &optional no-fold)
   (if (and value (stringp key))
       (let ((beg (point)) params med par parname parval)
 	(when (listp value)
@@ -197,7 +196,8 @@
 	    (setq parname (concat parname "*"))))
 	  (insert " " parname "=" parval))
 	(insert "\n")
-	(mew-header-fold-region beg (point) med))))
+	(unless no-fold
+	  (mew-header-fold-region beg (point) med)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -274,8 +274,8 @@
 		  (while (< i len)
 		    (setq c (aref str i))
 		    (cond
-		     ((or (char-equal c ?\t) (char-equal c 32))
-		      (setq i (1+ i)))
+		     ;; ((or (char-equal c ?\t) (char-equal c 32))
+		     ;; (setq i (1+ i)))
 		     ((char-equal c ?\")
 		      (aset tmp tmp-cnt c)
 		      (setq tmp-cnt (1+ tmp-cnt))
@@ -414,28 +414,11 @@ Remove anonymous addresses."
 	(concat addr "@" (mew-mail-domain))) ;; xxx
     addr))
 
-(defun mew-addrstr-expand-alias (alias)
-  (let ((addrs (mew-alias-get alias)))
-    (setq addrs (mapcar (function mew-chop) (mew-split addrs ?,)))
-    (setq addrs (delete "" addrs))
-    (mapcar (function mew-addrstr-append-domain) addrs)))
-
-(defun mew-addrstr-canonicalize-address (addr-str)
-  "Expand aliases for each addresses in ADDR-STR. 
-Then prepend (mew-mail-domain) if a domain part doesn't exist."
-  (let ((addrs (mapcar (function mew-chop) (mew-split addr-str ?,)))
-	addr ret)
-    (while addrs
-      (setq addr (car addrs))
-      (setq addrs (cdr addrs))
-      (setq ret (nconc ret (mew-addrstr-expand-alias addr))))
-    ret))
-
 (provide 'mew-header)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
