@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Feb  1, 1999
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -31,6 +30,16 @@
 
 (unless mew-summary-mode-map
   (setq mew-summary-mode-map (make-sparse-keymap))
+  (define-key mew-summary-mode-map "0"    'digit-argument)
+  (define-key mew-summary-mode-map "1"    'digit-argument)
+  (define-key mew-summary-mode-map "2"    'digit-argument)
+  (define-key mew-summary-mode-map "3"    'digit-argument)
+  (define-key mew-summary-mode-map "4"    'digit-argument)
+  (define-key mew-summary-mode-map "5"    'digit-argument)
+  (define-key mew-summary-mode-map "6"    'digit-argument)
+  (define-key mew-summary-mode-map "7"    'digit-argument)
+  (define-key mew-summary-mode-map "8"    'digit-argument)
+  (define-key mew-summary-mode-map "9"    'digit-argument)
   (define-key mew-summary-mode-map " "    'mew-summary-display)
   (define-key mew-summary-mode-map "."    'mew-summary-analyze-again)
   (define-key mew-summary-mode-map ":"
@@ -58,6 +67,7 @@
   (define-key mew-summary-mode-map "@"    'mew-summary-multi)
   (define-key mew-summary-mode-map "*"    'mew-summary-review)
   (define-key mew-summary-mode-map "y"    'mew-summary-save)
+  (define-key mew-summary-mode-map "Y"    'mew-summary-cite)
   (define-key mew-summary-mode-map "u"    'mew-summary-undo)
   (define-key mew-summary-mode-map "U"    'mew-summary-undo-all)
   (define-key mew-summary-mode-map "n"    'mew-summary-display-down)
@@ -82,7 +92,7 @@
   (define-key mew-summary-mode-map "\C-c\C-c" 'mew-summary-send-message)
   (define-key mew-summary-mode-map "\C-c\C-e" 'mew-summary-execute-external)
   (define-key mew-summary-mode-map "\C-c\C-y" 'mew-summary-execute-command)
-  (define-key mew-summary-mode-map "\C-c\C-i" 'mew-summary-insert-part)
+  (define-key mew-summary-mode-map "\C-c\C-i" 'mew-summary-find-file)
   (define-key mew-summary-mode-map "\C-c\C-f" 'mew-pgp-fetch-key)
   (define-key mew-summary-mode-map "\C-c\C-v" 'mew-pgp-select)
   (define-key mew-summary-mode-map "\C-c\C-s" 'mew-summary-isearch-forward)
@@ -95,7 +105,6 @@
   (define-key mew-summary-mode-map "\es"  'mew-summary-unshar)
   (define-key mew-summary-mode-map "\eb"  'mew-summary-burst-multi)
   (define-key mew-summary-mode-map "v"    'mew-summary-toggle-disp-msg)
-  (define-key mew-summary-mode-map "8"    'mew-summary-toggle-8bit)
   (define-key mew-summary-mode-map "\C-c\C-l" 'mew-summary-convert-local-cs)
   (define-key mew-summary-mode-map "\C-c\C-z" 'mew-summary-decode-pgp)
   (define-key mew-summary-mode-map "\C-c\C-x" 'mew-summary-x-face)
@@ -127,11 +136,14 @@
   (define-key mew-summary-mode-map "to"   'mew-thread-mark-refile)
   (define-key mew-summary-mode-map "t\ed" 'mew-thread-mark-unlink)
   (define-key mew-summary-mode-map "tu"   'mew-thread-unmark)
+  (define-key mew-summary-mode-map "z"    (make-sparse-keymap))
+  (define-key mew-summary-mode-map "z8"   'mew-summary-toggle-8bit)
   ;;
   ;; not provided in Virtual mode
   ;;
   (define-key mew-summary-mode-map "!"    'mew-summary-refile-again)
   (define-key mew-summary-mode-map "o"    'mew-summary-refile)
+  (define-key mew-summary-mode-map "c"    'mew-summary-copy)
   (define-key mew-summary-mode-map "d"    'mew-summary-delete)
   (define-key mew-summary-mode-map "\ed"  'mew-summary-unlink)
   (define-key mew-summary-mode-map "x"    'mew-summary-exec)
@@ -426,6 +438,7 @@
   (define-key mew-draft-attach-map "l"      'mew-attach-link)
   (define-key mew-draft-attach-map "m"      'mew-attach-multipart)
   (define-key mew-draft-attach-map "T"      'mew-attach-type)
+  (define-key mew-draft-attach-map "t"      'mew-attach-toggle)
   (define-key mew-draft-attach-map "G"      'mew-attach-gzip64)
   (define-key mew-draft-attach-map "B"      'mew-attach-base64)
   (define-key mew-draft-attach-map "Q"      'mew-attach-quoted-printable)
@@ -453,9 +466,13 @@
 ;;;
 
 (unless mew-input-map
-  (setq mew-input-map (make-sparse-keymap))
+  (setq mew-input-map
+	(if (boundp 'minibuffer-local-map)
+	    (copy-keymap minibuffer-local-map)
+	  (make-sparse-keymap)))
   (define-key mew-input-map " "    'mew-input-complete)
   (define-key mew-input-map "\t"   'mew-input-complete)
+  (define-key mew-input-map "?"    'mew-input-complete)
 ;;  (define-key mew-input-map "\177" 'backward-delete-char)
 ;;  (define-key mew-input-map [delete] 'backward-delete-char)
 ;;  (define-key mew-input-map "\C-h" 'mew-complete-backscroll)
@@ -540,7 +557,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2001 Mew developing team.
+;; Copyright (C) 2000-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
