@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar  2, 1997
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -15,7 +14,10 @@
 
 (defun mew-mark-unrefile (fld msg)
   "Delete refile state and delete the mark."
-  (mew-refile-reset fld msg))
+  (when (get-buffer fld)
+    (save-excursion
+      (set-buffer fld)
+      (mew-refile-reset msg))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -28,13 +30,13 @@
     (while msgs
       (setq msg (car msgs))
       (setq msgs (cdr msgs))
-      (setq msg-dsts (assoc msg (mew-sinfo-get-refile)))
+      (setq msg-dsts (mew-refile-get msg))
       (setq dsts (cdr msg-dsts))
       (if dsts ;; sanity check
 	  (if (setq tmp (assoc dsts dsts-msgses))
 	      (nconc tmp (list msg))	      
 	    (setq dsts-msgses (cons (list dsts msg) dsts-msgses))))
-      (mew-sinfo-set-refile (delq msg-dsts (mew-sinfo-get-refile))))
+      (mew-refile-reset msg))
     ;; refile at once
     (while dsts-msgses
       (mew-summary-mv-msgs src (car dsts-msgses))
@@ -81,7 +83,7 @@ DELS represents the messages to be deleted."
     (while msgs
       (setq msg (car msgs))
       (setq msgs (cdr msgs))
-      (setq dsts (cdr (assoc msg (mew-sinfo-get-refile))))
+      (setq dsts (cdr (mew-refile-get msg)))
       (while dsts
 	(setq dst (car dsts))
 	(setq dsts (cdr dsts))
@@ -154,7 +156,8 @@ DELS represents the messages to be deleted."
   "This function returns a list of message number."
   (save-excursion
     (let ((regex (mew-mark-regex mark))
-	  (msglist nil))
+	  (msglist nil)
+	  (case-fold-search nil))
       (goto-char (if begin begin (point-min)))
       (while (re-search-forward regex end t)
 	(setq msglist (cons (mew-summary-message-number) msglist)))
@@ -165,7 +168,8 @@ DELS represents the messages to be deleted."
 cons pairs of folder name and message number."
   (save-excursion
     (let ((regex (mew-mark-regex mark))
-          (msglist nil))
+          (msglist nil)
+	  (case-fold-search nil))
       (goto-char (point-min))
       (while (re-search-forward regex nil t)
         (setq msglist (cons 
@@ -175,18 +179,15 @@ cons pairs of folder name and message number."
                        msglist)))
       (nreverse msglist))))
 
-(defun mew-summary-mark-collect3 (mark)
-  "This function returns a list of line number."
+(defun mew-summary-mark-collect4 ()
   (save-excursion
-    (let ((regex (mew-mark-regex mark))
-	  (i 1)
-	  ret)
+    (let (ret mrk msg)
       (goto-char (point-min))
-      (while (not (eobp))
-	(if (looking-at regex)
-	    (setq ret (cons i ret)))
-	(forward-line)
-	(setq i (1+ i)))
+      (while (re-search-forward mew-regex-msg-mark nil t)
+	(setq msg (mew-match 1))
+	(setq mrk (string-to-char (mew-match 2)))
+	(setq ret (cons (cons msg mrk) ret))
+	(forward-line))
       (nreverse ret))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -273,7 +274,7 @@ NO-MSG also means that this function is being called in loop."
 	   (setq marked t))))
 	(t;; > oldlevel newlevel
 	 (setq case 7)
-	 (message "Can't mark here because '%s' is stronger than '%s'"
+	 (message "Cannot mark here because '%s' is stronger than '%s'"
 		  oldname newname))))
      (if (and msg fld marked)
 	 (mew-summary-mark-in-physical fld msg newmark))
@@ -449,6 +450,7 @@ for '\\[mew-summary-multi-forward]', '\\[mew-summary-unshar]', '\\[mew-summary-u
 (defun mew-summary-mark-all (&optional arg)
   "Put the '*' mark onto all messages which are not marked."
   (interactive "P")
+  (mew-decode-syntax-delete)
   (if arg
       (let ((begend (mew-summary-get-region)))
 	(mew-summary-mark-region (car begend) (cdr begend)))
@@ -458,7 +460,6 @@ for '\\[mew-summary-multi-forward]', '\\[mew-summary-unshar]', '\\[mew-summary-u
   "Put the '*' mark onto all messages which are not marked between
 BEG and END."
   (interactive "r")
-  (mew-decode-syntax-delete)
   (let ((regex (concat mew-regex-msg " "))
 	(mark mew-mark-review) ;; someday ...
 	fld msg alist)
@@ -480,6 +481,7 @@ BEG and END."
   (mew-decode-syntax-delete)
   (let ((regex (read-string "Regexp: "))
 	(mark mew-mark-review) ;; someday ...
+        (n 0)
 	fld msg alist)
     (while (string= regex "")
       (setq regex (read-string "Regexp: ")))
@@ -488,13 +490,21 @@ BEG and END."
       (while (re-search-forward regex nil t)
 	(when (looking-at "[^\n]*\r") ;; before thread info
 	  (mew-summary-mark-as mark)
+          (setq n (1+ n))
 	  (when (mew-virtual-p)
 	    (setq fld (mew-summary-folder-name))
 	    (setq msg (mew-summary-message-number))
 	    (mew-mark-alist-set alist fld msg)))
 	(forward-line)) ;; make search faster
       (set-buffer-modified-p nil))
-    (mew-summary-mark-in-physical-alist alist mark)))
+    (mew-summary-mark-in-physical-alist alist mark)
+    (cond
+     ((= n 1)
+      (message "1 message marked"))
+     ((> n 1)
+      (message "%d messages marked" n))
+     (t
+      (message "No message to be marked")))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -546,10 +556,11 @@ BEG and END."
 (defun mew-mark-undo-mark (mark &optional no-msg)
   "Undo MARK on the entire buffer.
 If optional argument NO-MSG is non-nil, no message is displayed."
-  (or no-msg (message "Unmarking ... "))
+  (or no-msg (message "Unmarking..."))
   (mew-decode-syntax-delete)
   (let* ((regex (mew-mark-regex mark))
 	 (func (mew-markdb-func-undo mark))
+	 (case-fold-search nil)
 	 alist fld msg)
     (or (fboundp func) (setq func nil))
     (save-excursion
@@ -564,7 +575,7 @@ If optional argument NO-MSG is non-nil, no message is displayed."
 	(forward-line))  ;; make search faster
       (set-buffer-modified-p nil)
       (mew-summary-unmark-in-physical-alist alist func)))
-  (or no-msg (message "Unmarking ... done")))
+  (or no-msg (message "Unmarking...done")))
 
 ;;
 
@@ -572,11 +583,11 @@ If optional argument NO-MSG is non-nil, no message is displayed."
   "Unmark all message marked with 'o' or 'D' or 'X'."
   (interactive)
   (let ((marks mew-summary-mark-undo-marks))
-    (message "Unmarking ... ")
+    (message "Unmarking...")
     (while marks
       (mew-mark-undo-mark (car marks) 'nomsg)
       (setq marks (cdr marks)))
-    (message "Unmarking ... done")))
+    (message "Unmarking...done")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -585,6 +596,7 @@ If optional argument NO-MSG is non-nil, no message is displayed."
 
 (defun mew-summary-exchange-mark (oldmark newmark)
   (let ((regex (mew-mark-regex oldmark))
+	(case-fold-search nil)
 	fld msg alist)
     (save-excursion
       (goto-char (point-min))
@@ -639,26 +651,35 @@ If optional argument NO-MSG is non-nil, no message is displayed."
 region. To cancel the '*' mark, use '\\[mew-summary-undo]' or
 '\\[mew-summary-undo-all]'."
   (interactive "P")
-  (cond
-   ((mew-virtual-p)
-    (if (not (mew-thread-p))
-	(message "Move to a physical folder first")
-      (let ((folder (substring (mew-summary-folder-name 'ext) 1))
-	    (msg (mew-summary-message-number)))
-	(if (not (and folder (get-buffer folder)))
-	    (message "No physical folder")
-	  (mew-summary-goto-folder nil folder 'no-ls)
-	  (if msg
-	      (mew-summary-jump-message msg)
-	    (goto-char (point-max)))
-	  (message "Now in %s. Type '%s' again"
-		   folder
-		   (substitute-command-keys
-		    "\\<mew-summary-mode-map>\\[mew-summary-exec]"))))))
-   (arg
-    (mew-summary-exec-region (mark) (point)))
-   (t
-    (mew-summary-exec-region (point-min) (point-max)))))
+  (let (beg end region)
+    (cond
+     (arg
+      (setq region (mew-summary-get-region))
+      (setq beg (car region))
+      (setq end (cdr region)))
+     (t
+      (setq beg (point-min))
+      (setq end (point-max))))
+    (cond
+     ((mew-folder-mdropp (mew-summary-folder-name 'ext))
+      (mew-summary-exec-mdrop beg end))
+     ((mew-virtual-p)
+      (if (not (mew-thread-p))
+	  (message "Move to a physical folder first")
+	(let ((folder (substring (mew-summary-folder-name 'ext) 1))
+	      (msg (mew-summary-message-number)))
+	  (if (not (and folder (get-buffer folder)))
+	      (message "No physical folder")
+	    (mew-summary-goto-folder nil folder 'no-ls)
+	    (if msg
+		(mew-summary-jump-message msg)
+	      (goto-char (point-max)))
+	    (message "Now in %s. Type '%s' again"
+		     folder
+		     (substitute-command-keys
+		      "\\<mew-summary-mode-map>\\[mew-summary-exec]"))))))
+     (t
+      (mew-summary-exec-region beg end)))))
 
 (defun mew-summary-exec-one (&optional arg)
   "Process the current marked messages.
@@ -714,7 +735,7 @@ all marked messages before the current message."
        (save-restriction
 	 (narrow-to-region beg end)
 	 (goto-char (point-min))
-	 (message "Collecting marks ... ")
+	 (message "Collecting marks...")
 	 (condition-case nil
 	     (let ((marks (mew-mark-get-all-marks))
 		   (src (mew-summary-folder-name 'ext))
@@ -731,8 +752,8 @@ all marked messages before the current message."
 		   (when msgs
 		     (when (= cnt 0)
 		       ;; opening...
-		       (setq mew-summary-buffer-process t)
-		       (message "Refiling and deleting ... ")
+		       (mew-summary-lock t "Refiling")
+		       (message "Refiling and deleting...")
 		       (mew-window-configure 'summary)
 		       (mew-current-set nil nil nil)
 		       (mew-decode-syntax-delete))
@@ -741,7 +762,7 @@ all marked messages before the current message."
 		     (setq func-sanity (mew-markdb-func-sanity mark))
 		     (when (and func-sanity
 				(setq err-folders (funcall func-sanity msgs)))
-		       (setq mew-summary-buffer-process nil)
+		       (mew-summary-unlock)
 		       (mew-warn
 			"Nothing proceeded. Folder(s) MUST be a file!: %s"
 			(mew-join "," err-folders)))
@@ -749,18 +770,21 @@ all marked messages before the current message."
 	       (if (= cnt 0)
 		   (message "No marks")
 		 ;; ending...
-		 (mew-mark-kill-line-region (point-min) (point-max))
-		 (mew-summary-folder-cache-save)
-                 (mew-touch-folder (mew-summary-folder-name 'ext))
-		 (setq mew-summary-buffer-process nil)
-		 (run-hooks 'mew-summary-exec-hook)
-		 (set-buffer-modified-p nil)
-		 (mew-summary-reset-mode-line (current-buffer))
 		 (mew-cache-clean-up)
-		 (message "Refiling and deleting ... done")))
+		 (mew-mark-kill-line-region (point-min) (point-max))
+		 (mew-summary-reset-mode-line (current-buffer))
+		 (mew-summary-folder-cache-save)
+		 (set-buffer-modified-p nil)
+		 (mew-summary-unlock)
+		 (when (and (eobp) (not (pos-visible-in-window-p)))
+		   (forward-line -1)
+		   ;; This ensures that some messages are displayed in Summary.
+		   (recenter))
+		 (run-hooks 'mew-summary-exec-hook)
+		 (message "Refiling and deleting...done")))
 	   (quit
 	    (set-buffer-modified-p nil)
-	    (setq mew-summary-buffer-process nil))))))))
+	    (mew-summary-unlock))))))))
 
 (defsubst mew-mark-kill-line ()
   (let (start)
@@ -780,60 +804,107 @@ all marked messages before the current message."
 	  (mew-mark-kill-line)))
     (set-buffer-modified-p nil)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Exec for mdrop
+;;;
+
+(defun mew-summary-exec-mdrop (beg end)
+  (when (mew-summary-exclusive-p)
+    (save-restriction
+      (narrow-to-region beg end)
+      ;; other marks...
+      (let ((gets (mew-summary-mark-collect mew-mark-refile))
+	    (dels (mew-summary-mark-collect mew-mark-delete))
+	    (fld (mew-summary-folder-name 'ext))
+	    usc siz msg xuid uid refs rmvs flds folders del)
+	(setq dels (nconc (mew-summary-mark-collect mew-mark-unlink) dels))
+	(while gets
+	  (setq msg (car gets))
+	  (setq gets (cdr gets))
+	  (setq xuid (mew-header-get-xuidl-from-file fld msg))
+	  (when xuid
+	    (setq usc (mew-scan-split-usc xuid))
+	    (setq uid (mew-scan-usc-uid usc))
+	    (setq siz (mew-scan-usc-size usc))
+	    (setq flds (cdr (mew-refile-get msg)))
+	    (setq del nil)
+	    (setq folders (mapcar (function list) flds)) ;; copying a list
+	    (if (member fld flds)
+		(setq folders (delete (list fld) folders)) ;; destructive
+	      (setq del t))
+	    (when folders
+	      (setq refs (cons (cons uid (cons siz (cons del folders))) refs)))
+	    (mew-refile-reset msg)))
+	(while dels
+	  (setq msg (car dels))
+	  (setq dels (cdr dels))
+	  (setq xuid (mew-header-get-xuidl-from-file fld msg))
+	  (when xuid
+	    (setq usc (mew-scan-split-usc xuid))
+	    (setq uid (mew-scan-usc-uid usc))
+	    (setq rmvs (cons uid rmvs))))
+	(setq refs (nreverse refs))
+	(setq rmvs (nreverse rmvs))
+	(if (or refs rmvs)
+	    (progn
+	      (mew-mark-kill-line-region (point-min) (point-max))
+	      (mew-pop-retrieve
+	       (mew-sinfo-get-mdrop-case) 'mdrop fld refs rmvs))
+	  (message "No messages to be processed"))))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Moving and removing
 ;;;
 
 (defun mew-summary-mv-msgs (src dsts-msgs)
-  (let* ((dsts (car dsts-msgs)) ;; (+foo +bar)
-	 (msgs (cdr dsts-msgs)) ;; (1 2 3)
+  (let* ((dsts (car dsts-msgs));; (+foo +bar)
+	 (msgs (cdr dsts-msgs));; (1 2 3)
 	 (myselfp (member src dsts))
 	 (refile-mark (regexp-quote (char-to-string mew-mark-refile)))
 	 msgs- msg srcfile dstfile dst num)
-    (if (mew-folder-remotep src)
-	() ;; IMAP
-      (if myselfp
-	  ;; msg stays in the src folder with the same number
-	  (progn
-	    (setq dsts (delete src dsts))
-	    (while msgs
-	      (setq msg (car msgs))
-	      (setq msgs (cdr msgs))
-	      (if (file-regular-p (mew-expand-folder src msg))
-		  (setq msgs- (cons msg msgs-))))
-	    (setq msgs- (nreverse msgs-))
-	    (setq msgs msgs-))
-	(setq dst (car dsts)) 
-	(setq dsts (cdr dsts))
-	(setq num (string-to-int (mew-folder-new-message dst 'num-only)))
-	(while msgs
-	  (setq srcfile (mew-expand-folder src (car msgs)))
-	  (setq msgs (cdr msgs))
-	  (when (and (file-exists-p srcfile) (file-writable-p srcfile))
-	    (setq msgs- (cons (int-to-string num) msgs-))
-	    (setq dstfile (mew-expand-folder dst (int-to-string num)))
-	    (setq num (1+ num))
-	    (rename-file srcfile dstfile 'override)))
-	(mew-touch-folder dst)
-	(setq msgs- (nreverse msgs-))
-	(setq src dst)
-	) ;; myselfp
-      (while dsts
-	(setq dst (car dsts)) 
-	(setq dsts (cdr dsts))
-	(setq num (string-to-int (mew-folder-new-message dst 'num-only)))
-	(setq msgs msgs-)
-	(while msgs
-	  (setq srcfile (mew-expand-folder src (car msgs)))
-	  (setq msgs (cdr msgs))
+    (if myselfp
+	;; msg stays in the src folder with the same number
+	(progn
+	  (setq dsts (delete src dsts))
+	  (while msgs
+	    (setq msg (car msgs))
+	    (setq msgs (cdr msgs))
+	    (if (file-regular-p (mew-expand-folder src msg))
+		(setq msgs- (cons msg msgs-))))
+	  (setq msgs- (nreverse msgs-))
+	  (setq msgs msgs-))
+      (setq dst (car dsts)) 
+      (setq dsts (cdr dsts))
+      (setq num (string-to-int (mew-folder-new-message dst 'num-only)))
+      (while msgs
+	(setq srcfile (mew-expand-folder src (car msgs)))
+	(setq msgs (cdr msgs))
+	(when (and (file-exists-p srcfile) (file-writable-p srcfile))
+	  (setq msgs- (cons (int-to-string num) msgs-))
 	  (setq dstfile (mew-expand-folder dst (int-to-string num)))
 	  (setq num (1+ num))
-	  (mew-link srcfile dstfile))
-	(mew-touch-folder dst)))
+	  (rename-file srcfile dstfile 'override)))
+      (mew-touch-folder dst)
+      (setq msgs- (nreverse msgs-))
+      (setq src dst)
+      );; myselfp
+    (while dsts
+      (setq dst (car dsts)) 
+      (setq dsts (cdr dsts))
+      (setq num (string-to-int (mew-folder-new-message dst 'num-only)))
+      (setq msgs msgs-)
+      (while msgs
+	(setq srcfile (mew-expand-folder src (car msgs)))
+	(setq msgs (cdr msgs))
+	(setq dstfile (mew-expand-folder dst (int-to-string num)))
+	(setq num (1+ num))
+	(mew-link srcfile dstfile))
+      (mew-touch-folder dst))
     (when myselfp
       (goto-char (point-min))
-      (setq msgs msgs-) ;; anyway
+      (setq msgs msgs-);; anyway
       (while msgs
 	;; illegal marks remain and the lines will be deleted.
 	(if (re-search-forward
@@ -842,38 +913,34 @@ all marked messages before the current message."
 	(setq msgs (cdr msgs))))))
 
 (defun mew-summary-rm-msgs (src dels)
-  (if (mew-folder-remotep src)
-      () ;; IMAP
-    (let* ((queue-p (mew-folder-queuep src))
-	   num srcfile dstfile mqifile)
-      (setq num (string-to-int
-		 (mew-folder-new-message mew-trash-folder 'num-only)))
-      ;; must be here after ensuring that +trash exists.
-      (while dels
-	(setq srcfile (mew-expand-folder src (car dels)))
-	(setq dels (cdr dels))
-	(setq dstfile (mew-expand-folder mew-trash-folder
-					 (int-to-string num)))
-	(setq num (1+ num))
-	(if (file-regular-p srcfile)
-	    ;; if not, the marked line will be deleted anyway.
-	    (rename-file srcfile dstfile 'override))
-	(when queue-p
-	  (setq mqifile (concat srcfile mew-queue-info-suffix))
-	  (if (file-regular-p mqifile)
-	      (delete-file mqifile))))
-      (mew-touch-folder mew-trash-folder))))
+  (let* ((queue-p (mew-folder-queuep src))
+	 num srcfile dstfile mqifile)
+    (setq num (string-to-int
+	       (mew-folder-new-message mew-trash-folder 'num-only)))
+    ;; must be here after ensuring that +trash exists.
+    (while dels
+      (setq srcfile (mew-expand-folder src (car dels)))
+      (setq dels (cdr dels))
+      (setq dstfile (mew-expand-folder mew-trash-folder
+				       (int-to-string num)))
+      (setq num (1+ num))
+      (if (file-regular-p srcfile)
+	  ;; if not, the marked line will be deleted anyway.
+	  (rename-file srcfile dstfile 'override))
+      (when queue-p
+	(setq mqifile (concat srcfile mew-queue-info-suffix))
+	(if (file-regular-p mqifile)
+	    (delete-file mqifile))))
+    (mew-touch-folder mew-trash-folder)))
 
 (defun mew-summary-clean-msgs (src dels)
-  (if (mew-folder-remotep src)
-      () ;; IMAP
-    (let (file)
-      (while dels
-	(setq file (mew-expand-folder src (car dels)))
-	(setq dels (cdr dels))
-	(if (file-regular-p file)
-	    ;; if not, the marked line will be deleted anyway.
-	    (delete-file file))))))
+  (let (file)
+    (while dels
+      (setq file (mew-expand-folder src (car dels)))
+      (setq dels (cdr dels))
+      (if (file-regular-p file)
+	  ;; if not, the marked line will be deleted anyway.
+	  (delete-file file)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -885,19 +952,20 @@ all marked messages before the current message."
     (cond
      ((char-equal char ?\r)
       (setq mew-mark-walk mew-mark-default-walk)
-      (message "Target mark was set to '%s'." (char-to-string mew-mark-walk)))
+      (message "Target mark was set to '%s'" (char-to-string mew-mark-walk)))
      (char (setq mew-mark-walk char)))))
 
 (defun mew-summary-down-mark (mark)
-  (forward-line)
-  (cond 
-   ((re-search-forward (mew-mark-regex mark) nil t)
-    (beginning-of-line)
-    t)
-   (t 
-    (forward-line -1)
-    (message "No more marked message")
-    nil)))
+  (let ((case-fold-search nil))
+    (forward-line)
+    (cond 
+     ((re-search-forward (mew-mark-regex mark) nil t)
+      (beginning-of-line)
+      t)
+     (t 
+      (forward-line -1)
+      (message "No more marked messages")
+      nil))))
 
 (defun mew-summary-display-review-down (&optional arg)
   "Jump to the message marked with '*' below."
@@ -908,12 +976,13 @@ all marked messages before the current message."
 	(mew-summary-display nil))))
 
 (defun mew-summary-up-mark (mark)
-  (cond 
-   ((re-search-backward (mew-mark-regex mark) nil t)
-    t)
-   (t 
-    (message "No more marked message")
-    nil)))
+  (let ((case-fold-search nil))
+    (cond
+     ((re-search-backward (mew-mark-regex mark) nil t)
+      t)
+     (t 
+      (message "No more marked messages")
+      nil))))
 
 (defun mew-summary-display-review-up (&optional arg)
   "Jump to the message marked with '*' above."
@@ -946,28 +1015,28 @@ all marked messages before the current message."
 	 (msgs (mew-dir-messages trashdir)))
     (if (null msgs)
 	(message "No messages to be removed in %s" mew-trash-folder)
-      (when (yes-or-no-p
+      (when (y-or-n-p
 	     (format "Remove all messages in %s? " mew-trash-folder))
-	(message "Removing all messages in %s ... " mew-trash-folder)
+	(message "Removing all messages in %s..." mew-trash-folder)
 	(mew-summary-clean-msgs mew-trash-folder msgs)
 	(mew-summary-clean-folder-cache mew-trash-folder)
-	(message "Removing all messages in %s ... done" mew-trash-folder)))))
+	(message "Removing all messages in %s...done" mew-trash-folder)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Clean up marks!
 ;;;
 
-(defun mew-mark-clean (&optional sum-buf)
+(defun mew-mark-clean (askp &optional sum)
   "Process marked messages for this folder."
-  (if sum-buf
-      (set-buffer sum-buf)
-    (setq sum-buf (mew-summary-folder-name 'ext)))
+  (if sum
+      (set-buffer sum)
+    (setq sum (mew-summary-folder-name 'ext)))
   (if (and (mew-summary-p)
-           (mew-summary-mark-exist-p
-            (list mew-mark-delete mew-mark-refile mew-mark-unlink))) ;; xxx
-      (if (y-or-n-p (format "Marks exist in %s. Process them? " sum-buf))
-	  (mew-summary-exec))))
+           (mew-summary-mark-exist-p mew-mark-clean)
+	   (or (not askp)
+	       (y-or-n-p (format "Marks exist in %s. Process them? " sum))))
+      (mew-summary-exec)))
 
 (defun mew-mark-init ()
   (add-hook 'kill-emacs-hook (function mew-mark-clean-up)))
@@ -983,7 +1052,7 @@ Typically called by kill-emacs-hook."
 	(setq buf (car bufs))
 	(setq bufs (cdr bufs))
 	(if (bufferp (get-buffer buf))
-	    (mew-mark-clean buf))))))
+	    (mew-mark-clean mew-ask-mark-process buf))))))
 
 ;; Saving marks is a really bad idea.
 ;; First because there is no way to fill the gap if the folder is newer
@@ -995,7 +1064,7 @@ Typically called by kill-emacs-hook."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
