@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1997
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -17,14 +16,14 @@
 
 (defun mew-mime-start-process (program options file)
   (let ((process-connection-type mew-connection-type1) pro)
-    (message "Starting %s ... " program)
+    (message "Starting %s..." program)
     (setq pro (apply (function mew-start-process-disp)
 		     (format "*mew %s*" program)
 		     nil
 		     program
 		     (append options (list file))))
     (set-process-sentinel pro 'mew-mime-start-process-sentinel)
-    (message "Starting %s ... done" program)
+    (message "Starting %s...done" program)
     (setq mew-process-file-alist (cons (cons pro file) mew-process-file-alist))
     t)) ;; to next part
 
@@ -35,9 +34,9 @@
     (setq mew-process-file-alist (delq al mew-process-file-alist))))
 
 (defun mew-mime-call-process (program options file)
-  (message "Calling %s ... " program)
+  (message "Calling %s..." program)
   (apply (function call-process) program file nil nil options)
-  (message "Calling %s ... done" program)
+  (message "Calling %s...done" program)
   t) ;; to next part
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -110,7 +109,7 @@
    "To save this part, type "
    "'\\<mew-summary-mode-map>\\[mew-summary-save]'.\n"
    "To insert this part in Message mode, type "
-   "'\\<mew-summary-mode-map>\\[mew-summary-insert-part]'.\n"
+   "'\\<mew-summary-mode-map>\\[mew-summary-display-asis]'.\n"
    "To execute a specified external command, type "
    "'\\<mew-summary-mode-map>\\[mew-summary-execute-command]'.\n"
    "To display this part as a specified Content-Type:, type "
@@ -148,7 +147,8 @@
      (insert
       (save-excursion (set-buffer cache) (buffer-substring begin end)))
      ;; If the "charset" parameter exists, this text is already decoded.
-     (unless (mew-syntax-get-param params "charset")
+     (unless (or mew-decode-broken
+		 (mew-charset-to-cs (mew-syntax-get-param params "charset")))
        (mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
      (when mew-insert-final-newline
        (save-excursion
@@ -178,7 +178,7 @@
 	       ;; format.el is buggy.
 	       (format-decode-region start (point-max) 'text/enriched)
 	     (args-out-of-range (message nil))) ;; just clear
-	   (enriched-mode nil))))
+	   (enriched-mode 0))))
       ;; Page breaks
       (when mew-break-pages
 	(goto-char (point-min))
@@ -219,7 +219,7 @@
   ;; called in Summary buffer
   (cond
    ((and (symbolp mew-prog-text/html-ext) (fboundp mew-prog-text/html-ext))
-    (message "Displaying HTML ... ")
+    (message "Displaying HTML...")
     (set-buffer (mew-buffer-message))
     (save-excursion
       (mew-elet
@@ -227,18 +227,19 @@
        (insert
 	(save-excursion (set-buffer cache) (buffer-substring begin end)))
        ;; If the "charset" parameter exists, this text is already decoded.
-       (unless (mew-syntax-get-param params "charset")
+       (unless (or mew-decode-broken
+		   (mew-charset-to-cs (mew-syntax-get-param params "charset")))
 	 (mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
        (funcall mew-prog-text/html-ext (point-min) (point-max))
        (mew-summary-display-postscript 'nohook)))
-    (message "Displaying HTML ... done"))
+    (message "Displaying HTML...done"))
    ((stringp mew-prog-text/html-ext)
     (when (> end begin)
-      (let ((file (format "%s.html" (mew-make-temp-name)))
+      (let ((file (format mew-format-html (mew-make-temp-name)))
 	    (orig mew-prog-text/html-ext-arg)
-	    arg charset wcs esqp)
+	    arg wcs esqp)
 	(save-excursion
-	  (message "Displaying Text/Html ... ")
+	  (message "Displaying Text/Html...")
 	  (set-buffer cache)
 	  (while orig
 	    (if (string-match "%s" (car orig))
@@ -249,17 +250,200 @@
 	    (setq orig (cdr orig)))
 	  (unless esqp (setq arg (cons file arg)))
 	  (setq arg (nreverse arg))
-	  (setq charset (mew-syntax-get-param params "charset"))
-	  (if charset 
-	      (setq wcs (mew-charset-to-cs charset))
-	    ;; probably called by C-uC-cC-e
-	    (setq wcs mew-cs-text-for-write))
+	  (setq wcs (mew-text/html-detect-cs begin end params))
 	  (mew-frwlet
 	   mew-cs-dummy wcs
 	   (write-region begin end file nil 'no-msg)
 	   (apply (function mew-start-process-disp)
 		  mew-prog-text/html-ext nil mew-prog-text/html-ext arg))
-	  (message "Displaying Text/Html ... done")))))))
+	  (message "Displaying Text/Html...done")))))))
+
+(defun mew-text/html-detect-cs (begin end params)
+  (let ((cs (mew-charset-to-cs (mew-syntax-get-param params "charset")))
+	(case-fold-search t))
+    (save-excursion
+      (goto-char begin)
+      (cond
+       ((or (re-search-forward
+	     (concat "<meta[ \t]+http-equiv=\"?content-type\"?[ \t]"
+		     "+content=\"[^;]+"
+		     ";[ \t]*charset=\"?\\([^\"]+\\)\"?[ \t]*/?>")
+	     (min end (+ begin 1024)) t)
+	    (re-search-forward
+	     (concat "<meta[ \t]+content=\"[^;]+"
+		     ";[ \t]*charset=\"?\\([^\"]+\\)\"?"
+		     "[ \t]+http-equiv=\"?content-type\"?[ \t]*/?>")
+	     (min end (+ begin 1024)) t))
+	(mew-charset-to-cs (mew-match 1)))
+       (cs cs)
+       (t  ;; charset eq "us-ascii", cs is nil.
+	(if mew-decode-broken
+	    (mew-charset-to-cs (mew-charset-guess-region begin end))
+	  ;; this text is no decoded.
+	  mew-cs-text-for-write))))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Text/XML
+;;;
+
+(defun mew-mime-text/xml (cache begin end &optional params)
+  ;; called in Message buffer
+  (if (and (symbolp mew-prog-text/xml) (fboundp mew-prog-text/xml))
+      (save-excursion
+	(mew-elet
+	 (let ((start (point)))
+	   (insert
+	    (save-excursion
+	      (set-buffer cache) (mew-buffer-substring begin end)))
+	   (funcall mew-prog-text/xml start (point-max)))))
+    (mew-elet
+     (insert " #     # #     # #\n"
+	     "  #   #  ##   ## #\n"
+	     "   # #   # # # # #\n"
+	     "    #    #  #  # #\n"
+	     "   # #   #     # #\n"
+	     "  #   #  #     # #\n"
+	     " #     # #     # #######\n"
+	     "\n\n")
+     (mew-insert "Size:\t\t%d bytes\n" (mew-region-bytes begin end cache))
+     (mew-insert "Browser:\t%s\n" (if (stringp mew-prog-text/xml-ext)
+				      mew-prog-text/xml-ext
+				    "none"))
+     (insert "\n")
+     (mew-mime-part-messages t))))
+
+(defun mew-mime-text/xml-ext (cache begin end &optional params)
+  ;; called in Summary buffer
+  (cond
+   ((and (symbolp mew-prog-text/xml-ext) (fboundp mew-prog-text/xml-ext))
+    (message "Displaying XML...")
+    (set-buffer (mew-buffer-message))
+    (save-excursion
+      (mew-elet
+       (mew-erase-buffer)
+       (insert
+	(save-excursion (set-buffer cache) (buffer-substring begin end)))
+       ;; If the "charset" parameter exists, this text is already decoded.
+       (unless (or mew-decode-broken
+		   (mew-charset-to-cs (mew-syntax-get-param params "charset")))
+	 (mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
+       (funcall mew-prog-text/xml-ext (point-min) (point-max))
+       (mew-summary-display-postscript 'nohook)))
+    (message "Displaying XML...done"))
+   ((stringp mew-prog-text/xml-ext)
+    (when (> end begin)
+      (let ((file (format mew-format-xml (mew-make-temp-name)))
+	    (orig mew-prog-text/xml-ext-arg)
+	    arg wcs esqp)
+	(save-excursion
+	  (message "Displaying Text/Xml...")
+	  (set-buffer cache)
+	  (while orig
+	    (if (string-match "%s" (car orig))
+		(progn
+		  (setq arg (cons (format (car orig) file) arg))
+		  (setq esqp t))
+	      (setq arg (cons (car orig) arg)))
+	    (setq orig (cdr orig)))
+	  (unless esqp (setq arg (cons file arg)))
+	  (setq arg (nreverse arg))
+	  (setq wcs (mew-text/xml-detect-cs begin end params))
+	  (mew-frwlet
+	   mew-cs-dummy wcs
+	   (write-region begin end file nil 'no-msg)
+	   (apply (function mew-start-process-disp)
+		  mew-prog-text/xml-ext nil mew-prog-text/xml-ext arg))
+	  (message "Displaying Text/Xml...done")))))))
+
+(defun mew-text/xml-detect-cs (begin end params)
+  (let ((cs (mew-charset-to-cs (mew-syntax-get-param params "charset")))
+	(case-fold-search t))
+    (save-excursion
+      (goto-char begin)
+      (cond
+       ((re-search-forward
+	 "<\\?xml.*encoding=['\"]\\([^'\"]+\\)['\"] *\\?>"
+	 (min end (+ begin 1024)) t)
+	(mew-charset-to-cs (mew-match 1)))
+       (cs cs)
+       (t  ;; charset eq "us-ascii", cs is nil.
+	(if mew-decode-broken
+	    (mew-charset-to-cs (mew-charset-guess-region begin end))
+	  ;; this text is no decoded.
+	  mew-cs-text-for-write))))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Application/Xml
+;;;
+
+(defun mew-mime-application/xml (cache begin end &optional params)
+  ;; called in Message buffer
+  (if (and (symbolp mew-prog-application/xml)
+	   (fboundp mew-prog-application/xml))
+      (save-excursion
+	(mew-elet
+	 (let ((start (point)))
+	   (insert
+	    (save-excursion
+	      (set-buffer cache) (mew-buffer-substring begin end)))
+	   (funcall mew-prog-application/xml start (point-max)))))
+    (mew-elet
+     (insert " #     # #     # #\n"
+	     "  #   #  ##   ## #\n"
+	     "   # #   # # # # #\n"
+	     "    #    #  #  # #\n"
+	     "   # #   #     # #\n"
+	     "  #   #  #     # #\n"
+	     " #     # #     # #######\n"
+	     "\n\n")
+     (mew-insert "Size:\t\t%d bytes\n" (mew-region-bytes begin end cache))
+     (mew-insert "Browser:\t%s\n" (if (stringp mew-prog-application/xml-ext)
+				      mew-prog-application/xml-ext
+				    "none"))
+     (insert "\n")
+     (mew-mime-part-messages t))))
+
+(defun mew-mime-application/xml-ext (cache begin end &optional params)
+  ;; called in Summary buffer
+  (cond
+   ((and (symbolp mew-prog-application/xml-ext) (fboundp mew-prog-application/xml-ext))
+    (message "Displaying XML...")
+    (set-buffer (mew-buffer-message))
+    (save-excursion
+      (mew-elet
+       (mew-erase-buffer)
+       (insert
+	(save-excursion (set-buffer cache) (buffer-substring begin end)))
+       (funcall mew-prog-application/xml-ext (point-min) (point-max))
+       (mew-summary-display-postscript 'nohook)))
+    (message "Displaying XML...done"))
+   ((stringp mew-prog-application/xml-ext)
+    (when (> end begin)
+      (let ((file (format "%s.xml" (mew-make-temp-name)))
+	    (orig mew-prog-application/xml-ext-arg)
+	    arg wcs esqp)
+	(save-excursion
+	  (message "Displaying Application/Xml...")
+	  (set-buffer cache)
+	  (while orig
+	    (if (string-match "%s" (car orig))
+		(progn
+		  (setq arg (cons (format (car orig) file) arg))
+		  (setq esqp t))
+	      (setq arg (cons (car orig) arg)))
+	    (setq orig (cdr orig)))
+	  (unless esqp (setq arg (cons file arg)))
+	  (setq arg (nreverse arg))
+	  (setq wcs mew-cs-binary)
+	  (mew-frwlet
+	   mew-cs-dummy wcs
+	   (write-region begin end file nil 'no-msg)
+	   (apply (function mew-start-process-disp)
+		  mew-prog-application/xml-ext nil
+		  mew-prog-application/xml-ext arg))
+	  (message "Displaying Application/Xml...done")))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -407,7 +591,7 @@
 	(progn
 	  (mew-elet (insert "\n"))
 	  (mew-mime-part-messages nil))
-      (message "Displaying an MS document ... ")
+      (message "Displaying an MS document...")
       (setq file1 (mew-make-temp-name))
       (save-excursion
 	(set-buffer cache)
@@ -417,22 +601,29 @@
       (if (eq prog mew-prog-application/msword)
  	  (mew-frwlet
  	   'utf-8 mew-cs-dummy
- 	   (call-process prog nil nil nil file1 file2)
-	   (insert-file-contents file2))
+	   (if mew-use-old-wvhtml
+	       (call-process prog nil nil nil file1 file2)
+	     (call-process prog nil nil nil
+			   (concat "--targetdir=" (file-name-directory file2))
+			   file1 
+			   (file-name-nondirectory file2)))
+	   (let ((buffer-file-coding-system)) ;; to prevent the side effect
+	     (insert-file-contents file2)))
 	(mew-frwlet
 	 'utf-8 mew-cs-dummy
 	 (call-process prog nil (current-buffer) nil file1)))
       (if (file-exists-p file1) (delete-file file1))
       (if (file-exists-p file2) (delete-file file2))
       (save-excursion
-	(w3m-region (point-min) (point-max)))
-      (message "Displaying an MS document ... done"))))
+	(w3m-region (point-min) (point-max)
+		    (w3m-expand-file-name-as-url (file-name-directory file2))))
+      (message "Displaying an MS document...done"))))
 
 (provide 'mew-mime)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
