@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Aug 17, 1994
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -74,6 +73,12 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     ("+batchmode=on" "+language=en")
     ("--verify" "--batch")))
 
+(defconst mew-prog-old-pgpv-arg
+  '(("+batchmode=on" "+language=en")
+    ("+batchmode=on" "+language=en" "+force=on")
+    ("+batchmode=on" "+language=en")
+    ("--decrypt" "--batch"))) ;; --verify does not extract original data
+
 (defconst mew-prog-arg-output '("-o" "-o" "-o" "--output"))
 (defconst mew-prog-arg-input '(nil "-o" nil nil))
 (defconst mew-prog-arg-luserid '("-u" "-u" "-u" "--local-user"))
@@ -109,6 +114,12 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defconst mew-pgp-msg-enter
   '("Enter" "Enter" "Enter" "xxx"))
 
+(defconst mew-pgp-msg-overwrite
+  '("Overwrite (y/N)\\? "
+    "Overwrite (y/N)\\? "
+    "Overwrite (y/N)\\? "
+    "Overwrite (y/N)\\? "))
+
 (defconst mew-pgp-msg-enter-pass 
   '("Enter pass phrase: "
     "Enter pass phrase: "
@@ -227,6 +238,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (when (mew-debug 'pgp)
     (save-excursion
       (set-buffer (get-buffer-create mew-buffer-debug))
+      (goto-char (point-max))
       (insert (format "\n<%s>\n%s\n" label string)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -317,7 +329,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 		  (setq ret mew-pgp-result-unsup)
 		;; this line must be nil since this function is used
 		;; by the decryption function, too, for signed-then-encrypted
-		;; messages. We can't tell whether or not signatures exist
+		;; messages. We cannot tell whether or not signatures exist
 		;; from the outside of the cipher.
 		))))
       ;; Signature result is found.
@@ -344,11 +356,14 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	      ;; PGP uses "unknown" for validity internally, but
 	      ;; prints "undefined" instead of "unknown".
 	      (setq ret (concat ret " UNDEFINED"))
-	    (setq ret (concat ret " COMPLETE"))))))
+	    (goto-char (point-min))
+	    (if (search-forward "expired" nil t)
+		(setq ret (concat ret " EXPIRED"))
+	      (setq ret (concat ret " COMPLETE")))))))
     ret))
 
 (defun mew-pgp-verify (file1 file2)
-  (message "PGP verifying ... ")
+  (message "PGP verifying...")
   (let ((ioption (mew-pgp-get mew-prog-arg-input))
 	(buf (generate-new-buffer mew-buffer-prefix))
 	ret)
@@ -368,11 +383,11 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 		       (list file2 file1))))
       (setq ret (mew-pgp-verify-check)))
     (mew-remove-buffer buf)
-    (message "PGP verifying ... done")
+    (message "PGP verifying...done")
     ret))
 
 (defun mew-pgp-verify-old (file)
-  (message "PGP verifying ... ")
+  (message "PGP verifying...")
   (let ((buf (generate-new-buffer mew-buffer-prefix))
 	(file1 (mew-make-temp-name))
 	verify)
@@ -382,11 +397,11 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
       (apply (function mew-call-process-lang)
 	     (mew-pgp-get mew-prog-pgpv)
 	     nil t nil 
-	     (append (mew-pgp-get mew-prog-pgpv-arg)
+	     (append (mew-pgp-get mew-prog-old-pgpv-arg)
 		     (list (mew-pgp-get mew-prog-arg-output) file1 file)))
       (setq verify (mew-pgp-verify-check)))
     (mew-remove-buffer buf)
-    (message "PGP verifying ... done")
+    (message "PGP verifying...done")
     (list file1 verify)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -408,7 +423,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     ret))
 
 (defun mew-pgp-encrypt (file1 decrypters)
-  (message "PGP encrypting ... ")
+  (message "PGP encrypting...")
   (let ((roption (mew-pgp-get mew-prog-arg-ruserid))
 	(file2 (mew-make-temp-name))
 	(buf (generate-new-buffer mew-buffer-prefix))
@@ -441,8 +456,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	       (append (mew-pgp-get mew-prog-pgpe-arg) decrypters)))
       (setq check (mew-pgp-encrypt-check))
       (mew-remove-buffer buf)
-      (message "PGP encrypting ... done")
-      (list file2 nil file3 nil check)))) ;; both ctes are 7bit
+      (message "PGP encrypting...done")
+      (list file2 "7bit" file3 "7bit" check)))) ;; both ctes are 7bit
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -452,7 +467,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defun mew-pgp-decrypt (file1 file2)
   ;; file1 is a key file. just ignore.
   ;; file2 is an encrypted file with PGP.
-  (message "PGP decrypting ... ")
+  (message "PGP decrypting...")
   (setq mew-pgp-running 'decrypting)
   (setq mew-pgp-string nil)
   (setq mew-pgp-decrypt-msg nil)
@@ -472,7 +487,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (set-process-filter process 'mew-pgp-process-filter1)
     (set-process-sentinel process 'mew-pgp-process-sentinel)
     (mew-rendezvous mew-pgp-running)
-    (message "PGP decrypting ... done")
+    (message "PGP decrypting...done")
     (if (file-exists-p file3)
 	(let ((buf (generate-new-buffer mew-buffer-prefix)))
 	  (save-excursion
@@ -512,7 +527,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
       (or alg micalg))))
 
 (defun mew-pgp-sign (file1)
-  (message "PGP signing ... ")
+  (message "PGP signing...")
   (setq mew-pgp-running 'signing)
   (setq mew-pgp-string nil)
   (setq mew-pgp-sign-msg nil)
@@ -534,7 +549,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (set-process-filter process 'mew-pgp-process-filter1)
     (set-process-sentinel process 'mew-pgp-process-sentinel)
     (mew-rendezvous mew-pgp-running)
-    (message "PGP signing ... done")
+    (message "PGP signing...done")
     (if (not (file-exists-p file2)) ;; for unpredictable error
 	(mew-passwd-set-passwd (mew-pgp-passtag) nil))
     (list file2 nil (mew-pgp-get-micalg) mew-pgp-sign-msg))) ;; return
@@ -611,6 +626,11 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (process-send-string process (format "%s\n" (mew-pgp-passphrase)))
     (set-process-filter process 'mew-pgp-process-filter2))
 
+   ;; overwrite a previous data with a new data. (multiple data is unsupported)
+   ((string-match (mew-pgp-get mew-pgp-msg-overwrite) string)
+    (process-send-string process "y\n")
+    (set-process-filter process 'mew-pgp-process-filter1))
+
    ;; just in case
    ((string-match (mew-pgp-get mew-pgp-msg-enter) string)
     (setq mew-pgp-failure mew-pgp-err-other)
@@ -656,6 +676,11 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (setq mew-pgp-failure mew-pgp-err-seckey-or-secring)
     (set-process-filter process 'mew-pgp-process-filter3))
 
+   ;; overwrite a previous data with a new data. (multiple data is unsupported)
+   ((string-match (mew-pgp-get mew-pgp-msg-overwrite) string)
+    (process-send-string process "y\n")
+    (set-process-filter process 'mew-pgp-process-filter2))
+
    ;; just in case
    ((string-match (mew-pgp-get mew-pgp-msg-enter) string)
     (setq mew-pgp-failure mew-pgp-err-other)
@@ -703,7 +728,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 
 (defsubst mew-pgp-encode-message (type &optional ask-singer)
   (if (null mew-pgp-ver)
-      (message "%s doesn't exist" mew-prog-pgp)
+      (message "%s does not exist" mew-prog-pgp)
     (if (and ask-singer (string-match "signature" (symbol-name type)))
 	(mew-draft-make-message type (car (mew-input-address "Who's key? : ")))
       (mew-draft-make-message type))))
@@ -716,18 +741,18 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defun mew-pgp-check-old-pgp ()
   (goto-char (point-min))
   (if (re-search-forward (concat "^" mew-pgp-encryption-begin) nil t)
+      ;; this may be 'pgp-signature, but we hope clearsig is used...
       'pgp-encryption
     (goto-char (point-min))
     (if (re-search-forward (concat "^" mew-pgp-signature-begin) nil t)
 	'pgp-signature
       nil)))
 
-
 (defun mew-summary-decode-pgp ()
   "Decrypting/verifying old-fashioned PGP messages."
   (interactive)
   (if (null mew-pgp-ver)
-      (message "%s doesn't exist" mew-prog-pgp)
+      (message "%s does not exist" mew-prog-pgp)
     (mew-summary-msg
      (let* ((fld (mew-summary-folder-name))
 	    (msg (mew-summary-message-number))
@@ -789,7 +814,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   "Extract the PGP key for the inputed user on '.'. in attachments"
   (interactive)
   (if (not (mew-attach-not-line012-1))
-      (message "Can't link here.")
+      (message "Cannot link here")
     (let* ((error nil)
 	   (nums (mew-syntax-nums))
 	   (subdir (mew-attach-expand-path mew-encode-syntax nums))
@@ -801,7 +826,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
       ;; attachdir / file
       (setq filepath (mew-random-filename attachdir 1 nil mew-pgp-key-suffix))
       (if (null filepath)
-	  (message "Could not make a file for pgp key, sorry.")
+	  (message "Cannot make a file for pgp key, sorry")
 	(setq file (file-name-nondirectory filepath))
 	(setq user (car (mew-input-address
 			 "Who's key? (%s): " (mew-get-my-address))))
@@ -831,7 +856,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 	      (write-region begin end filepath nil 'no-msg))))
 	(mew-remove-buffer buf)
 	(if error
-	    (message "can't extract pgp key for %s" user)
+	    (message "Cannot extract pgp key for %s" user)
 	  (setq mew-encode-syntax
 		(mew-syntax-insert-entry
 		 mew-encode-syntax 
@@ -860,7 +885,7 @@ public keyring."
 (defun mew-mime-pgp-keys-ext (cache begin end &optional params)
   "A function to add PGP keys to your public keyring."
   (if (not mew-pgp-ver)
-      (message "PGP is not found")
+      (message "PGP not found")
     (when (y-or-n-p "Add this PGP key onto your public keyring? ")
       (setq mew-pgp-tmp-file (mew-make-temp-name))
       (save-excursion
@@ -870,13 +895,13 @@ public keyring."
 	 (write-region begin end mew-pgp-tmp-file nil 'no-msg))
 	(set-buffer (mew-buffer-message))
 	(mew-elet
-	 (message "Adding PGP keys ... ")
+	 (message "Adding PGP keys...")
 	 (apply (function mew-call-process-lang)
 		(mew-pgp-get mew-prog-pgpk)
 		nil t nil 
 		(append (mew-pgp-get mew-prog-pgpk-add-arg)
 			(list mew-pgp-tmp-file)))
-	 (message "Adding PGP keys ... done")
+	 (message "Adding PGP keys...done")
 	 (insert "\n\n"
 		 "**************** IMPORTANT NOTE ****************\n"
 		 "When Mew adds PGP keys onto your public keyring,\n"
@@ -891,7 +916,7 @@ public keyring."
  	   (insert "\"pgp -ke\" and \"pgp -ks\" to change them.\n"))
 	  ((eq mew-pgp-ver mew-pgp-verg)
 	   (insert "\"gpg --edit-key\" to change them.\n")))
-	 (insert "If you don't know what TRUST and VALIDITY is,\n"
+	 (insert "If you do not know what TRUST and VALIDITY is,\n"
 		 "you should learn the web of trust system BEFORE\n"
 		 "using PGP to protect your privacy.\n"
 		 "**************** IMPORTANT NOTE ****************\n")
@@ -947,11 +972,11 @@ public keyring."
 	(setq uri (format mew-pgp-keyserver-url-template userid))))
       (if uri
 	  (mew-pgp-fetch uri)
-	(message "Can't find PGP public key's information.")))))
+	(message "Cannot find PGP public key's information")))))
 
 (defun mew-pgp-fetch (uri)
   (let ((buf (generate-new-buffer mew-buffer-prefix)))
-    (message "PGP key fetching ...")
+    (message "PGP key fetching...")
     (mew-piolet
      mew-cs-autoconv mew-cs-autoconv
      (setq mew-pgp-fetch-process
@@ -971,7 +996,7 @@ public keyring."
     (setq mew-pgp-fetch-process nil)))
 
 (defun mew-pgp-fetch-process-sentinel (process event)
-  (message "PGP key fetching ... done")
+  (message "PGP key fetching...done")
   (let* ((buf (process-buffer process)))
     (save-excursion
       (set-buffer buf)
@@ -1021,7 +1046,7 @@ public keyring."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2001 Mew developing team.
+;; Copyright (C) 1994-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
