@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Oct  2, 1996
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -23,17 +22,20 @@ execute 'mew-summary-pick-with-external'. Otherwise,
    (let ((folder (mew-summary-folder-name))
 	 (pattern (if arg (mew-input-grep-pattern) (mew-input-pick-pattern)))
 	 (preline 0)
-	 msgs msgsback threadmsgs total linenum)
+	 msgs msgsback threadmsgs total linenum n)
      (mew-sinfo-set-find-key nil) ;; force to ask a user
-     (message "Picking messages in %s ..." folder)
+     (message "Picking messages in %s..." folder)
      (if arg
 	 (setq msgs (mew-summary-pick-with-external folder pattern))
        (setq msgs (mew-summary-pick-with-mewls folder pattern)))
      (setq msgsback msgs)
-     (message "Picking messages in %s ... done" folder)
+     (message "Picking messages in %s...done" folder)
      (if (null msgs)
-	 (message "No message to be marked.")
-       (message "Marking messages ... ")
+	 (message "No message to be marked")
+       (setq n (length msgs))
+       (if (= n 1)
+ 	   (message "Marking 1 message...")
+ 	 (message "Marking %d messages..." n))
        (save-excursion
 	 ;; Thread folder
 	 (when (mew-thread-p)
@@ -63,10 +65,12 @@ execute 'mew-summary-pick-with-external'. Otherwise,
 		 (forward-line))
 	       (setq msgs (cdr msgs)))
 	     (set-buffer-modified-p nil))))
-       (message "Marking messages ... done")))))
+       (if (= n 1)
+ 	   (message "Marking 1 message...done")
+ 	 (message "Marking %d messages...done" n))))))
 
 (defun mew-summary-pick-with-mewls (folder pattern)
-  "A function to pick messages matching PATTERN with 'mewls'."
+  "A function to pick messages matching PATTERN with 'mewls'"
   (let ((buf (generate-new-buffer mew-buffer-prefix))
 	msgs)
     (save-excursion
@@ -114,8 +118,7 @@ This function MUST return text in which each line begins with a file name.")
 	 (msgs (mew-dir-messages "."))
 	 buf)
     ;; no sort here
-    (if (null msgs)
-	()
+    (when msgs
       (save-excursion
 	(setq buf (generate-new-buffer mew-buffer-prefix))
 	(set-buffer buf)
@@ -166,7 +169,7 @@ keyword, execute this command with '\\[universal-argument]'."
     (cond
      ((and (equal mew-mark-review mark)
 	   (or (not (string= fld ofld)) (not (string= msg omsg))))
-      (mew-summary-display-asis 'nolimit)
+      (mew-summary-display-asis)
       (setq top t))
      ((or (null mwin)
 	  (not (equal mew-mark-review mark))
@@ -174,11 +177,11 @@ keyword, execute this command with '\\[universal-argument]'."
 	  (save-excursion (set-buffer mbuf) (eobp)))
       (if (not (mew-summary-down-mark mew-mark-review))
 	  (setq search nil)
-	(mew-summary-display-asis 'nolimit)
+	(mew-summary-display-asis)
 	(setq top t))))
     (setq mwin (get-buffer-window mbuf))
     (if (not search)
-	(message "No more marked message.")
+	(message "No more marked messages")
       (select-window mwin)
       (unwind-protect
 	  (progn
@@ -188,7 +191,7 @@ keyword, execute this command with '\\[universal-argument]'."
 		  (isearch-highlight (- end (length key)) end)
 		  (recenter (/ (window-height) 2)))
 	      (goto-char (point-max))
-	      (message "Keyword '%s' is not found." key)
+	      (message "Keyword '%s' is not found" key)
 	      (recenter -1)))
 	(select-window cwin)))))
 
@@ -216,7 +219,7 @@ keyword, execute this command with '\\[universal-argument]'."
     (cond
      ((and (equal mew-mark-review mark)
 	   (or (not (string= fld ofld)) (not (string= msg omsg))))
-      (mew-summary-display-asis 'nolimit)
+      (mew-summary-display-asis)
       (setq bottom t))
      ((or (null mwin)
 	  (not (equal mew-mark-review mark))
@@ -224,11 +227,11 @@ keyword, execute this command with '\\[universal-argument]'."
 	  (save-excursion (set-buffer mbuf) (bobp)))
       (if (not (mew-summary-up-mark mew-mark-review))
 	  (setq search nil)
-	(mew-summary-display-asis 'nolimit)
+	(mew-summary-display-asis)
 	(setq bottom t))))
     (setq mwin (get-buffer-window mbuf))
     (if (not search)
-	(message "No more marked message.")
+	(message "No more marked messages")
       (select-window mwin)
       (unwind-protect
 	  (progn
@@ -238,7 +241,7 @@ keyword, execute this command with '\\[universal-argument]'."
 		  (isearch-highlight beg (+ beg (length key)))
 		  (recenter (/ (window-height) 2)))
 	      (goto-char (point-min))
-	      (message "Keyword '%s' is not found." key)
+	      (message "Keyword '%s' is not found" key)
 	      (recenter 0)))
 	(select-window cwin)))))
 
@@ -341,7 +344,7 @@ keyword, execute this command with '\\[universal-argument]'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
