@@ -273,6 +273,7 @@
   (when (mew-debug 'net)
     (save-excursion
       (set-buffer (get-buffer-create mew-buffer-debug))
+      (goto-char (point-max))
       (insert (format "\n<%s>\n%s\n" label string)))))
 
 (defun mew-pop-filter (process string)
@@ -307,7 +308,7 @@
   				(if (< 10000 siz)
   				    (/ (buffer-size) (/ siz 100))
   				  (/ (* (buffer-size) 100) siz)))))
-       (mew-summary-set-process-status fld "Receiving" progress)))
+       (mew-summary-set-process-status fld "Retrieving" progress)))
      ;; xxx
      ;; Process's buffer
      (goto-char (point-max))
@@ -708,11 +709,11 @@
       (mew-pop-set-status pnm "quit")
       (mew-pop-command-quit pro pnm))
      ((= n 1)
-      (mew-pop-message pnm "Receiving 1 message in background...")
+      (mew-pop-message pnm "Retrieving 1 message in background...")
       (mew-pop-set-status pnm "retr")
       (mew-pop-command-retr pro pnm))
      (t
-      (mew-pop-message pnm "Receiving %d messages in background..." n)
+      (mew-pop-message pnm "Retrieving %d messages in background..." n)
       (mew-pop-set-status pnm "retr")
       (mew-pop-command-retr pro pnm)))))
 
@@ -787,10 +788,9 @@
     (when (string= mew-cs-eol "\r\n")
       (goto-char (point-min))
       (while (search-forward "\r\n" nil t) (replace-match "\n" nil t)))
-    ;; deleting \n.\n
+    ;; deleting .\n
     (goto-char (point-max))
-    (forward-line -2)
-    (end-of-line)
+    (forward-line -1)
     (delete-region (point) (point-max))
     ;; unescape ^.
     (goto-char (point-min))
@@ -803,8 +803,8 @@
       (goto-char (point-min))
       (when uid
 	(if case
-	    (mew-header-insert xmu (concat uid " " siz " " case))
-	  (mew-header-insert xmu (concat uid " " siz)))))
+	    (mew-header-insert xmu (concat uid " " siz " " case) 'no-fold)
+	  (mew-header-insert xmu (concat uid " " siz) 'no-fold))))
     (catch 'write-error
       (condition-case nil
 	  (mew-frwlet 
@@ -861,7 +861,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2001 Mew developing team.
+;; Copyright (C) 1999-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
