@@ -394,7 +394,7 @@ Otherwise append 'mew-scan-form-header' to FORM."
       (string-match ":" range)))
 
 (defun mew-summary-retrieve (&optional no-flush)
-  "Retrieve received messages to +inbox asynchronously.
+  "Retrieve messages to +inbox asynchronously.
 If called with '\\[universal-argument]', +queue is not flushed."
   (interactive "P")
   (let* ((case mew-case-input)
@@ -446,7 +446,7 @@ If called with '\\[universal-argument]', +queue is not flushed."
     xuidl))
 
 (defun mew-summary-retrieve-message (&optional rev-del)
-  "Retrieve the entire of a truncated('T') message.
+  "Retrieve the rest of a truncated('T') message.
 If 'mew-pop-delete' is 't', delete the message from the mailbox.
 When executed with '\\[universal-argument]', 'mew-pop-delete' is considered reversed."
   (interactive "P")
@@ -472,7 +472,7 @@ When executed with '\\[universal-argument]', 'mew-pop-delete' is considered reve
 	   (mew-pop-retrieve case 'get fld rtrs))))))))
 
 (defun mew-summary-mark-retrieve-message (&optional rev-del)
-  "Retrieve the entire of truncated('T') messages marked with '*'.
+  "Retrieve the rest of truncated('T') messages marked with '*'.
 If 'mew-pop-delete' is 't', delete the message from the mailbox.
 When executed with '\\[universal-argument]', 'mew-pop-delete' is considered reversed."
   (interactive "P")
@@ -512,11 +512,13 @@ When executed with '\\[universal-argument]', 'mew-pop-delete' is considered reve
 	(mbox-command-arg (mew-mbox-command-arg case))
 	(inbox (mew-inbox-folder case))
 	args)
-    (if mbox-command-arg
-	(setq args (list "-e" mbox-command "-m" mbox-command-arg))
-      (setq args (list "-e" mbox-command)))
-    (setq args (append args (mew-scan-mewls-src inbox)))
-    (mew-scan args  nil nil 'flush)))
+    (if (not (mew-which-exec mbox-command))
+	(message "'%s' not found!" mbox-command)
+      (if mbox-command-arg
+	  (setq args (list "-e" mbox-command "-m" mbox-command-arg))
+	(setq args (list "-e" mbox-command)))
+      (setq args (append args (mew-scan-mewls-src inbox)))
+      (mew-scan args  nil nil 'flush))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -603,7 +605,7 @@ current position."
 ;;; Sub-functions for Scan
 ;;;
 
-(defun mew-scan-header ()
+(defun mew-scan-header (&optional draftp)
   (let (vec key med str n)
     (setq vec (make-vector (length mew-scan-fields) ""))
     (save-restriction
@@ -618,7 +620,7 @@ current position."
 	  (mew-header-goto-next)
 	  (when (setq n (mew-member-case-equal key mew-scan-fields))
 	    ;; xxx this may be able to tune up.
-	    (mew-header-decode-region key med (point))
+	    (mew-header-decode-region key med (point) draftp)
 	    ;; Need to inherit properties.
 	    ;; So, we use buffer-substring, not mew-buffer-substring.
 	    (setq str (buffer-substring med (1- (point))))
@@ -753,6 +755,7 @@ current position."
 	 (pnm (process-name process))
 	 (folder (mew-scan-pnm-to-bnm pnm))
 	 (virtualp (mew-folder-virtualp folder))
+	 (draftp (mew-folder-draftp folder))
 	 vec)
     (mew-filter
      (goto-char (point-max))
@@ -761,7 +764,7 @@ current position."
      (goto-char (point-min))
      (while (and (re-search-forward mew-eoh nil t) (not (eobp)))
        (mew-set-buffer-multibyte t)
-       (setq vec (mew-scan-header))
+       (setq vec (mew-scan-header draftp))
        (mew-set-buffer-multibyte nil)
        (mew-scan-insert-line folder vec width nil virtualp)
        (forward-line)
@@ -894,7 +897,7 @@ current position."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
