@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Oct  2, 1996
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -139,11 +138,18 @@
 (defsubst mew-syntax-get-param (ctl member)
   (nth 1 (assoc member ctl)))
 
+(defun mew-syntax-treat-filename-default-function (file)
+  (if (stringp file)
+      (mew-replace-white-space
+       (mew-chop (file-name-nondirectory file)))))
+
 (defun mew-syntax-get-filename (cdpl &optional ctl)
   (let ((file (mew-syntax-get-param cdpl "filename")))
     ;; for broken MUAs
     (if (and (null file) mew-use-name-parameter ctl)
 	(setq file (mew-syntax-get-param ctl "name")))
+    (if mew-syntax-treat-filename-function
+	(setq file (funcall mew-syntax-treat-filename-function file)))
     file))
 
 ;; need to setq
@@ -309,7 +315,7 @@
 	       (or (button-press-event-p event)
 		   (button-release-event-p event)))
       (setq str (toolbar-button-help-string (event-toolbar-button event)))
-      ;; last-pressed-toolbar-button can't be used.
+      ;; last-pressed-toolbar-button cannot be used.
       (if (string-match mew-regex-part-icon str)
 	  (setq ret (mew-match 1 str))))
     (or ret
@@ -367,6 +373,11 @@
 	      nil))
 	   (t nil)))))))
 
+(defun mew-summary-message-number2 ()
+  (save-excursion
+    (mew-summary-goto-message)
+    (mew-summary-message-number)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; mew-encode-syntax
@@ -376,10 +387,19 @@
 				      privacy decrypters)
   ;; cid is just for beauty
   ;; if cdp is *non-nil*, set cdp from file.
-  (let* ((attr (mew-ctdb-by-file file))
-	 (ct (mew-ctdb-ct attr)))
-    (or cte (setq cte (mew-ctdb-cte attr)))
-    (if (null ctl) (setq ctl (list ct)))
+  (let* (ct ctdb)
+    (cond
+     (ctl
+      (setq ct (car ctl))
+      (setq ctdb (mew-ctdb-by-ct ct)))
+     (t
+      (setq ctdb (mew-ctdb-by-file file))
+      (setq ct (mew-ctdb-ct ctdb))
+      (unless ct
+	(setq ct (mew-content-type)) ;; xxx case?
+	(setq ctdb (mew-ctdb-by-ct ct)))
+      (setq ctl (list ct))))
+    (or cte (setq cte (mew-ctdb-cte ctdb)))
     (if cdp (setq cdp (mew-syntax-cdp-format ct file)))
     (vconcat [single] (list file decrypters privacy ctl cte cd cid cdp))))
 
@@ -659,7 +679,7 @@
 	    (if ichar
 		(setq ct (concat ct "(*" ichar ")"))
 	      (setq ct (concat ct "(guess)"))))))
-    (if mew-inherit-alt (setq ct (concat ct "*")))
+    (if (and dec mew-inherit-alt) (setq ct (concat ct "*")))
     (setq ct (mew-substring ct lt 'cnt))
 
     (if (null privacy)
@@ -715,20 +735,17 @@
   (set-buffer (marker-buffer mew-marker-decode-syntax-begin)))
 
 (defun mew-decode-syntax-delete ()
-  (if (mew-decode-syntax-p)
-      (let ((cbuf (current-buffer))
-	    (pos (make-marker)))
-	(set-buffer (mew-decode-syntax-buffer))
-	(mew-xinfo-set-icon-spec nil)
-	(mew-summary-toolbar-update)
-	(set-marker pos (point))
+  (when (mew-decode-syntax-p)
+    (save-excursion
+      (set-buffer (mew-decode-syntax-buffer))
+      (mew-xinfo-set-icon-spec nil)
+      (mew-summary-toolbar-update)
+      (save-excursion
 	(mew-elet
-	 (delete-region (mew-decode-syntax-begin) (mew-decode-syntax-end)))
-	(mew-decode-syntax-remove)
-	(goto-char (marker-position pos))
-	(mew-highlight-cursor-line)
-	(set-buffer-modified-p nil)
-	(set-buffer cbuf))))
+	 (delete-region (mew-decode-syntax-begin) (mew-decode-syntax-end))))
+      (mew-decode-syntax-remove)
+      (mew-highlight-cursor-line)
+      (set-buffer-modified-p nil))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -975,7 +992,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
