@@ -558,7 +558,7 @@ threads are created, see 'mew-use-complete-thread'."
   (mew-thread-only
    (mew-summary-msg-or-part
     (let ((column (mew-vinfo-get-column))
-	  indent cindent fld msg alist)
+	  indent cindent fld msg alist bottom)
       (mew-summary-goto-message)
       (mew-summary-thread-move-cursor)
       (mew-decode-syntax-delete)
@@ -583,14 +583,18 @@ threads are created, see 'mew-use-complete-thread'."
 		  (setq msg (mew-summary-message-number))
 		  (mew-mark-alist-set alist fld msg))))
 	    (forward-line)))
+	(beginning-of-line)
+	(setq bottom (point))
 	(mew-summary-mark-in-physical-alist alist mark))
       (mew-summary-goto-message)
       (mew-decode-syntax-delete)
       ;; for C-x C-x
       (beginning-of-line)
-      (let ((zmacs-regions nil))
-	(push-mark (point) t t))
-      (mew-summary-display-after mew-summary-mark-direction)
+      (let ((zmacs-regions nil)
+	    ;; To treat this thread as if it were a single message.
+	    (mew-summary-down-function (lambda () (goto-char bottom))))
+	(push-mark (point) t t)
+	(mew-summary-display-after mew-summary-mark-direction))
       alist))))
 
 (defsubst mew-thread-unmark-one ()
@@ -827,7 +831,7 @@ a top node, move onto the top of the previous thread."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2001 Mew developing team.
+;; Copyright (C) 2000-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
