@@ -64,14 +64,14 @@
 (defvar mew-prog-image/*-ext-arg '("-geometry" "+0+0"))
 
 (defvar mew-prog-application/msword "wvHtml")
-(defvar mew-prog-application/msexcel "xlHtml")
-(defvar mew-prog-application/mspowerpoint "pptHtml")
+(defvar mew-prog-application/msexcel "xlhtml")
+(defvar mew-prog-application/mspowerpoint "ppthtml")
 
 (provide 'mew-unix)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
