@@ -25,7 +25,7 @@
   :group 'mew)
 
 (defgroup mew-env nil
-  "Basic envinorment."
+  "Basic environment."
   :group 'mew)
 
 (defgroup mew-folder nil
@@ -485,8 +485,8 @@ use a string. (e.g. \"110\")"
   :type 'string)
 
 (defcustom mew-pop-auth 'apop
-  "*The authentication method for POP3. Choose either 'pass or 'apop. 
-'pass means the authentication with USER/PASS (ie plain password).
+  "*The authentication method for POP3.
+'pass means the authentication with USER/PASS (i.e. plain password).
 'apop means the authentication with APOP.
 t means SASL according to mew-pop-auth-list"
   :group 'mew-pop
@@ -656,7 +656,7 @@ If KEY is a list of strings, match-function is applied according to
 'mew-scan-form-list-list-type'. If a match found out of the strings,
 the corresponding SCAN-FORM is returned.
 
-Candicate values for 'mew-scan-form-list-string-type' and
+Candidate values for 'mew-scan-form-list-string-type' and
 'mew-scan-form-list-list-type' are as follows:
 
 	'regex		Regular expression.
@@ -957,8 +957,13 @@ invalid. Otherwise, 'update is used for range in the case."
 ;;;
 
 (defcustom mew-use-full-window nil
-  "*Dynamic window configuration when nil. This variable will be obsolated
-because mew will support mew-window-percent(e.g 50, 100, etc.)."
+  "*If non-nil, the entire frame is used for Mew.
+Otherwise, windows are configured dynamically."
+  :group 'mew-env
+  :type 'boolean)
+
+(defcustom mew-use-other-frame nil
+  "*If non-nil, a new frame is created when a draft is prepared. "
   :group 'mew-env
   :type 'boolean)
 
@@ -1035,11 +1040,21 @@ according to 'mew-mime-multipart-alternative-list'."
   :type 'boolean)
 
 (defcustom mew-use-text-body t
-  "*If non-nil, A single Text/* body or the first Text/* part in a top level
+  "*If non-nil, a single Text/* body or the first Text/* part in a top level
 multipart is displayed with its header."
   :group 'mew-summary
   :type 'boolean)
 
+(defcustom mew-use-nfs-hack nil
+  "*If non-nil, Mew takes some workarounds for NFS."
+  :group 'mew-env
+  :type 'boolean)
+
+(defcustom mew-use-old-wvhtml nil
+  "*If non-nil, Mew calls wvHtml in the old argument style."
+  :group 'mew-message
+  :type 'boolean)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Appearance
@@ -1130,7 +1145,7 @@ where the cursor jumped to the bottom."
   :type 'boolean)
 
 (defcustom mew-summary-region-include-cursor-line nil
-  "*This value decides wether of not the cursor line is included
+  "*This value decides wether or not the cursor line is included
 to a region."
   :group 'mew-summary
   :type '(choice (const :tag "Include if the cursor is not on the beginning of the line" nil)
@@ -1139,7 +1154,8 @@ to a region."
 
 (defvar mew-highlight-timer-interval 3)
 
-(defcustom mew-syntax-treat-filename-function nil
+(defcustom mew-syntax-treat-filename-function
+  (function mew-syntax-treat-filename-default-function)
   "*A function to modify file names specified by Content-Disposition:"
   :group 'mew-summary
   :type 'symbol)
@@ -1288,9 +1304,9 @@ confirmed to be used."
 (defcustom mew-cite-fields `(,mew-from: ,mew-subj: ,mew-date:)
   "*The fields that you want to extract as citation label. 
 If you change this valuable, you must change mew-cite-format.
-The value of the first field becomes the first argment for mew-cite-format.
-(e.g. The default first argment is a value of From: field.)
-The value of the second field becomes the second argment for mew-cite-format.
+The value of the first field becomes the first argument for mew-cite-format.
+(e.g. The default first argument is a value of From: field.)
+The value of the second field becomes the second argument for mew-cite-format.
 ....
 If this is nil, label is not generated."
   :group 'mew-cite
@@ -1382,7 +1398,7 @@ signature files, use 'c-sig.el'."
 
 (defcustom mew-signature-insert-last nil 
   "*If *non-nil*, the signature file is inserted in the last of body. 
-Otherwise, it is inserted at the currect point. If you created multipart
+Otherwise, it is inserted at the current point. If you created multipart
 and mew-signature-as-lastpart is *non-nil*, this variable is ignored."
   :group 'mew-draft
   :type 'boolean)
@@ -1612,7 +1628,7 @@ directory for copy, etc.  See also 'mew-summary-preserve-dir'."
   
 (defcustom mew-file-append-p nil
   "*If *non-nil*, a message or a part is appended to the existing file
-on '\\<mew-summary-mode-map>\\[mew-summary-save]'. Otherwise overwrited."
+on '\\<mew-summary-mode-map>\\[mew-summary-save]'. Otherwise overwrote."
   :group 'mew-summary
   :type 'boolean)
 
@@ -1706,7 +1722,7 @@ The format is like this:
 
 (defcustom mew-refile-auto-refile-skip-any-mark nil
   "*If *non-nil*, 'mew-summary-auto-refile' does not touch
-any alredy marked message."
+any already marked message."
   :group 'mew-refile
   :type 'boolean)
 
@@ -1761,7 +1777,7 @@ The syntax is exactly the same as 'mew-refile-guess-alist'."
   :type 'boolean)
 
 (defcustom mew-case-guess-addition nil
-  "*If *non-nil*, new gussed cases are added to old cases.
+  "*If *non-nil*, new guessed cases are added to old cases.
 Otherwise, the old cases are overridden."
   :group 'mew-draft
   :type 'boolean)
@@ -1779,7 +1795,7 @@ Otherwise, the old cases are overridden."
 'trashonly : Really remove messages marked with 'D' if in the +trash folder.
              In other folders, refile to the +trash folder.
 'uselist   : Really remove messages marked with 'D' if in a folder found
-	     in @samp{mew-msg-rm-folder-list}. In other folders, refile 
+	     in mew-msg-rm-folder-list. In other folders, refile 
              to the +trash folder.
 otherwise  : considered as 'totrash."
   :group 'mew-refile
@@ -1879,12 +1895,13 @@ MODE is one of \"date\" (by chronological order) or
                \"num\"  (by numerical order) or
                \"postnum\" (by numerical order of postfix numeric) or
                \"text\" (by alphabetical order) or
-               \"ml\"   (by alphabetical order with ml prefix removed).
+               \"ml\"   (by alphabetical order with ml prefix removed) or
+               \"mlnum\" (by numerical order of ml number).
 (nil means \"text\")."
   :group 'mew-summary
   :type 'sexp)
 
-(defvar mew-sort-modes '("date" "num" "postnum" "text" "ml"))
+(defvar mew-sort-modes '("date" "num" "postnum" "text" "ml" "mlnum"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -1894,11 +1911,11 @@ MODE is one of \"date\" (by chronological order) or
 (defvar mew-range-all "0")
 
 (defvar mew-range-str-all "all")
-
 (defvar mew-range-str-update "update")
+(defvar mew-range-str-last "last:")
 
 (defcustom mew-input-range-list
-  `(,mew-range-str-update ,mew-range-str-all)
+  `(,mew-range-str-update ,mew-range-str-all ,mew-range-str-last)
   "*A list used by range completion."
   :group 'mew-complete
   :type '(repeat string))
@@ -2286,7 +2303,13 @@ Bad example:
 as a file name in addition to the legal FILENAME parameter of
 Content-Disposition:."
   :group 'mew-message
-  :type 'mew-summary)
+  :type 'boolean)
+
+(defcustom mew-broken-parameter-list '("name" "filename")
+  "*A list of parameter names whose value contains non-ASCII strings
+produced by broken MUAs."
+  :group 'mew-message
+  :type '(repeat string))
 
 (defvar mew-decode-ws-fields '("Subject:"))
 
@@ -2300,11 +2323,16 @@ the warning is displayed on X-Mew:.
 Level 1: syntax is correct, but not recommenced.
 Level 2: syntax error.")
 
+(defcustom mew-encode-singlepart-hook nil
+  "*Hook called before making a single part."
+  :group 'mew-draft
+  :type 'hook)
+
 (provide 'mew-vars)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
