@@ -282,7 +282,7 @@ in draft buffer.")
     ("audio/x-mpeg" "\\.mpga$\\|\\.mp[23]$" mew-b64 mew-prog-audio mew-icon-audio)
     ;;
     ("image/gif"   "\\.gif$"   mew-b64 mew-prog-image mew-icon-image)
-    ("image/tiff"  "\\.tiff$"  mew-b64 mew-prog-image mew-icon-image)
+    ("image/tiff"  "\\.tif?f$" mew-b64 mew-prog-image mew-icon-image)
     ("image/jpeg"  "\\.jpe?g$" mew-b64 mew-prog-image mew-icon-image)
     ("image/png"   "\\.png$"   mew-b64 mew-prog-image mew-icon-image)
     ("image/x-xwd" "\\.xwd$"   mew-b64 mew-prog-image mew-icon-image)
@@ -712,10 +712,15 @@ present, mew-face-header-marginal is used."
     (,mew-mark-delete 2 0 2 0 0 0 0)
     (,mew-mark-unlink 2 0 2 0 0 0 0)
     (,mew-mark-refile 2 0 2 0 0 0 0))
-  "*A list of cursor actions after marking.
-0 means staying.
-1 means moving according to the direction,
-2 means moving according to the direction then displaying the next message.
+  "*A list of cursor action spec.
+The cursor action spec is a list of a mark and seven cursor
+actions after marking.
+
+0th (the first element of a list) is a mark value. A mark value is
+ASCII code of the mark. For example, the value of the '*' mark
+(mew-mark-review) is 42.
+
+Seven values following a mark value means as follows:
 
 1st is the case of no mark.
 2nd is the case where the new mark is equal to the old one.
@@ -729,6 +734,13 @@ present, mew-face-header-marginal is used."
 7th is the case where level of the new mark is smaller than that of the 
     old one.
 
+The value of cursor actions means as follows:
+
+	0 means staying.
+	1 means moving according to the direction,
+	2 means moving according to the direction 
+	  then displaying the next message.
+
 For more detail, see mew-mark-put-mark and mew-mark-afterstep.")
 
 (defsubst mew-markas-nth (mark case)
@@ -874,7 +886,7 @@ An example is as follows:
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2001 Mew developing team.
+;; Copyright (C) 2000-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
