@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Oct  2, 1996
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -13,7 +12,7 @@
 ;;; Virtual info
 ;;;
 
-(defvar mew-vinfo-list '("count" "func" "top" "db" "thread-p"))
+(defvar mew-vinfo-list '("count" "func" "top" "db" "thread-p" "column"))
 
 (mew-blinfo-defun 'mew-vinfo mew-vinfo-list)
 
@@ -64,7 +63,7 @@ execute 'mew-summary-virtual-with-external'. Otherwise,
 'mew-summary-virtual-with-internal' is called."
   (interactive "P")
   (if (not (mew-summary-or-virtual-p))
-      (message "This command cannot be used in this mode.")
+      (message "This command cannot be used in this mode")
     (if ext
 	(if mew-summary-virtual-with-external-function
 	    (mew-summary-virtual-with-external)
@@ -72,7 +71,7 @@ execute 'mew-summary-virtual-with-external'. Otherwise,
       (mew-summary-virtual-with-internal))))
 
 (defun mew-summary-virtual-with-internal ()
-  "Create VIrtual mode with mewls."
+  "Create Virtual mode with mewls."
   (let* ((str (mew-input-string "Virtual folder name %s(%s): " "" "virtual"))
 	 (vfolder (concat "++" str)) ;; xxx
 	 (flds (mew-input-folders (mew-summary-folder-name)))
@@ -91,7 +90,7 @@ execute 'mew-summary-virtual-with-external'. Otherwise,
 (defvar mew-summary-virtual-with-external-function
   'mew-summary-virtual-with-grep
   "*A function to be called by '\\[universal-argument] \\<mew-summary-mode-map>\\[mew-summary-virtual]'.
-This function MUST returns ...")
+This function MUST returns a file name which contains message numbers.")
 
 (defun mew-summary-virtual-with-external ()
   "Create Virtual mode with 'mew-summary-virtual-with-external-function'."
@@ -129,7 +128,7 @@ This function MUST returns ...")
 	(if (= (length msgs) 1) (setq msgs (cons "/dev/null" msgs)))
 	(cd dir)
 	(mew-erase-buffer)
-	(message "Picking in %s ..." (car flds))
+	(message "Picking in %s..." (car flds))
 	(while msgs
 	  (goto-char (point-max))
 	  (setq nxt (nthcdr mew-prog-grep-max-msgs msgs))
@@ -138,7 +137,7 @@ This function MUST returns ...")
 		 mew-prog-vgrep nil t nil
 		 (append mew-prog-vgrep-opts (list pattern) msgs))
 	  (setq msgs nxt))
-	(message "Picking in %s ... done." (car flds)))
+	(message "Picking in %s...done" (car flds)))
       (goto-char (point-min))
       (setq msgs nil)
       (while (not (eobp))
@@ -177,7 +176,7 @@ This function MUST returns ...")
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2001 Mew developing team.
+;; Copyright (C) 1996-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
