@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Nov  1, 2001
+;; Revised: Feb 25, 2002
 
 ;;; Commentary:
 
@@ -45,7 +45,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "2.1"
+(defconst mew-version-number "2.2"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -203,8 +203,12 @@ set mew-touch-folder-p to t"
     (let* ((dir (expand-file-name mew-mail-path))
 	   (file (expand-file-name mew-summary-touch-file dir))
 	   (time1 (mew-file-get-time dir))
-	   time2)
+	   time2 curtime)
       (when (file-writable-p file)
+	(setq curtime (current-time))
+	(if (and (equal (nth 1 curtime) (nth 1 time1))
+		 (equal (nth 0 curtime) (nth 0 time1)))
+	    (sleep-for 1))
 	(write-region "touched by Mew.(test)" nil file nil 'no-msg)
 	(if (file-exists-p file) (delete-file file))
 	(setq time2 (mew-file-get-time dir))
@@ -605,10 +609,11 @@ the lower window is not zero, switch to the buffer."
 	 (len (length frames))
 	 (i 0))
     (catch 'loop
+      (while frames
       (if (equal me (car frames))
 	  (throw 'loop i))
       (setq i (1+ i))
-      (setq frames (cdr frames)))
+      (setq frames (cdr frames))))
     (setq i (- len i 1))
     (format "%s%d" mew-buffer-message i)))
 
@@ -671,6 +676,7 @@ It is typically called by kill-emacs-hook."
 ;;; Regular expressions
 ;;;
 
+(defvar mew-regex-msg-show nil)
 (defvar mew-regex-msg-or-part nil)
 (defvar mew-regex-msg-mark nil)
 (defvar mew-regex-msg-review nil)
@@ -691,11 +697,8 @@ It is typically called by kill-emacs-hook."
 
 (defun mew-regex-setup ()
   (setq mew-eoh (format "^\\(%s\\|\\)$" (regexp-quote mew-header-separator)))
-  (setq mew-regex-msg-or-part
-	(concat
-	 (mew-mark-list-regex (cons ?  mew-mark-show-list))
-	 "\\|"
-	 mew-regex-part))
+  (setq mew-regex-msg-show (mew-mark-list-regex (cons ?  mew-mark-show-list)))
+  (setq mew-regex-msg-or-part (concat mew-regex-msg-show "\\|" mew-regex-part))
   (setq mew-regex-msg-mark (concat mew-regex-msg mew-regex-mark))
   (setq mew-regex-msg-review (mew-mark-regex mew-mark-review))
   (setq mew-regex-msg-delete (mew-mark-regex mew-mark-delete))
@@ -867,7 +870,7 @@ Mew remain, so you can resume with buffer operations."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2001 Mew developing team.
+;; Copyright (C) 1994-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
